@@ -53,10 +53,15 @@ void QgsExportLayersInformationAlgorithm::initAlgorithm( const QVariantMap & )
 
 QString QgsExportLayersInformationAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Creates a polygon layer with features corresponding to the extent of selected layer(s).\n\n"
+  return QObject::tr( "This algorithm creates a polygon layer with features corresponding to the extent of selected layer(s).\n\n"
                       "Additional layer details - CRS, provider name, file path, layer name, subset filter, abstract and attribution - are attached as attributes to each feature." );
 }
 
+QString QgsExportLayersInformationAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Creates a polygon layer with features corresponding to the extent of selected layer(s)." );
+}
+
 QgsExportLayersInformationAlgorithm *QgsExportLayersInformationAlgorithm::createInstance() const
 {
   return new QgsExportLayersInformationAlgorithm();
@@ -64,7 +69,7 @@ QgsExportLayersInformationAlgorithm *QgsExportLayersInformationAlgorithm::create
 
 bool QgsExportLayersInformationAlgorithm::prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback )
 {
-  const QList< QgsMapLayer * > layers = parameterAsLayerList( parameters, QStringLiteral( "LAYERS" ), context );
+  const QList<QgsMapLayer *> layers = parameterAsLayerList( parameters, QStringLiteral( "LAYERS" ), context );
   for ( QgsMapLayer *layer : layers )
   {
     if ( !mCrs.isValid() )
@@ -105,14 +110,13 @@ QVariantMap QgsExportLayersInformationAlgorithm::processAlgorithm( const QVarian
   outFields.append( QgsField( QStringLiteral( "attribution" ), QMetaType::Type::QString ) );
 
   QString outputDest;
-  std::unique_ptr< QgsFeatureSink > outputSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, outputDest, outFields,
-      Qgis::WkbType::Polygon, mCrs ) );
+  std::unique_ptr<QgsFeatureSink> outputSink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, outputDest, outFields, Qgis::WkbType::Polygon, mCrs ) );
 
-  const QList< QgsMapLayer * > layers = parameterAsLayerList( parameters, QStringLiteral( "LAYERS" ), context );
+  const QList<QgsMapLayer *> layers = parameterAsLayerList( parameters, QStringLiteral( "LAYERS" ), context );
 
   const double step = layers.size() > 0 ? 100.0 / layers.size() : 1;
   int i = 0;
-  for ( const std::unique_ptr< QgsMapLayer > &layer : mLayers )
+  for ( const std::unique_ptr<QgsMapLayer> &layer : mLayers )
   {
     i++;
     if ( feedback->isCanceled() )
@@ -132,9 +136,9 @@ QVariantMap QgsExportLayersInformationAlgorithm::processAlgorithm( const QVarian
     {
       const QVariantMap parts = QgsProviderRegistry::instance()->decodeUri( layer->dataProvider()->name(), layer->source() );
       attributes << layer->dataProvider()->name()
-                 << parts[ QStringLiteral( "path" ) ]
-                 << parts[ QStringLiteral( "layerName" ) ]
-                 << parts[ QStringLiteral( "subset" ) ];
+                 << parts[QStringLiteral( "path" )]
+                 << parts[QStringLiteral( "layerName" )]
+                 << parts[QStringLiteral( "subset" )];
     }
     else
     {
@@ -168,6 +172,8 @@ QVariantMap QgsExportLayersInformationAlgorithm::processAlgorithm( const QVarian
       throw QgsProcessingException( writeFeatureError( outputSink.get(), parameters, QStringLiteral( "OUTPUT" ) ) );
   }
 
+  outputSink->finalize();
+
   QVariantMap outputs;
   outputs.insert( QStringLiteral( "OUTPUT" ), outputDest );
   return outputs;
