@@ -54,7 +54,7 @@ QString QgsFieldCalculatorAlgorithm::outputName() const
 
 QList<int> QgsFieldCalculatorAlgorithm::inputLayerTypes() const
 {
-  return QList<int>() << static_cast< int >( Qgis::ProcessingSourceType::Vector );
+  return QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::Vector );
 }
 
 Qgis::ProcessingFeatureSourceFlags QgsFieldCalculatorAlgorithm::sourceFlags() const
@@ -71,44 +71,36 @@ void QgsFieldCalculatorAlgorithm::initParameters( const QVariantMap &configurati
   fieldTypes.reserve( 11 );
   icons.reserve( 11 );
   for ( const auto &type :
-        std::vector < std::pair< QMetaType::Type, QMetaType::Type > >
-{
-  {QMetaType::Type::Double, QMetaType::Type::UnknownType },
-  {QMetaType::Type::Int, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QString, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QDate, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QTime, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QDateTime, QMetaType::Type::UnknownType },
-  {QMetaType::Type::Bool, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QByteArray, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QStringList, QMetaType::Type::UnknownType },
-  {QMetaType::Type::QVariantList, QMetaType::Type::Int },
-  {QMetaType::Type::QVariantList, QMetaType::Type::Double }
-} )
+        std::vector<std::pair<QMetaType::Type, QMetaType::Type>> {
+          { QMetaType::Type::Double, QMetaType::Type::UnknownType },
+          { QMetaType::Type::Int, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QString, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QDate, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QTime, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QDateTime, QMetaType::Type::UnknownType },
+          { QMetaType::Type::Bool, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QByteArray, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QStringList, QMetaType::Type::UnknownType },
+          { QMetaType::Type::QVariantList, QMetaType::Type::Int },
+          { QMetaType::Type::QVariantList, QMetaType::Type::Double }
+        } )
   {
     fieldTypes << QgsVariantUtils::typeToDisplayString( type.first, type.second );
     icons << QgsFields::iconForFieldType( type.first, type.second );
   }
 
-  std::unique_ptr< QgsProcessingParameterString > fieldName = std::make_unique< QgsProcessingParameterString > ( QStringLiteral( "FIELD_NAME" ), QObject::tr( "Field name" ), QVariant(), false );
-  std::unique_ptr< QgsProcessingParameterEnum > fieldType = std::make_unique< QgsProcessingParameterEnum > ( QStringLiteral( "FIELD_TYPE" ), QObject::tr( "Result field type" ), fieldTypes, false, 0 );
+  auto fieldName = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "FIELD_NAME" ), QObject::tr( "Field name" ), QVariant(), false );
+  auto fieldType = std::make_unique<QgsProcessingParameterEnum>( QStringLiteral( "FIELD_TYPE" ), QObject::tr( "Result field type" ), fieldTypes, false, 0 );
   fieldType->setMetadata(
-  {
-    QVariantMap( {{
-        QStringLiteral( "widget_wrapper" ),
-        QVariantMap(
-        { {
-            QStringLiteral( "icons" ), icons
-          }}
-        )
-      }} )
-  } );
+    { QVariantMap( { { QStringLiteral( "widget_wrapper" ), QVariantMap( { { QStringLiteral( "icons" ), icons } } ) } } )
+    }
+  );
 
-  std::unique_ptr< QgsProcessingParameterNumber > fieldLength = std::make_unique< QgsProcessingParameterNumber > ( QStringLiteral( "FIELD_LENGTH" ), QObject::tr( "Result field length" ), Qgis::ProcessingNumberParameterType::Integer, QVariant( 0 ), false, 0 );
-  std::unique_ptr< QgsProcessingParameterNumber > fieldPrecision = std::make_unique< QgsProcessingParameterNumber > ( QStringLiteral( "FIELD_PRECISION" ), QObject::tr( "Result field precision" ), Qgis::ProcessingNumberParameterType::Integer, QVariant( 0 ), false, 0 );
-  std::unique_ptr< QgsProcessingParameterExpression > expression = std::make_unique< QgsProcessingParameterExpression> ( QStringLiteral( "FORMULA" ), QObject::tr( "Formula" ), QVariant(), QStringLiteral( "INPUT" ), false );
+  auto fieldLength = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "FIELD_LENGTH" ), QObject::tr( "Result field length" ), Qgis::ProcessingNumberParameterType::Integer, QVariant( 0 ), false, 0 );
+  auto fieldPrecision = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "FIELD_PRECISION" ), QObject::tr( "Result field precision" ), Qgis::ProcessingNumberParameterType::Integer, QVariant( 0 ), false, 0 );
+  auto expression = std::make_unique<QgsProcessingParameterExpression>( QStringLiteral( "FORMULA" ), QObject::tr( "Formula" ), QVariant(), QStringLiteral( "INPUT" ), false );
 
-  expression->setMetadata( QVariantMap( {{"inlineEditor", true}} ) );
+  expression->setMetadata( QVariantMap( { { "inlineEditor", true } } ) );
 
   addParameter( fieldName.release() );
   addParameter( fieldType.release() );
@@ -130,6 +122,12 @@ QString QgsFieldCalculatorAlgorithm::shortHelpString() const
                       "Note that if \"Field name\" is an existing field in the layer then all the rest of the field settings are ignored." );
 }
 
+QString QgsFieldCalculatorAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Computes a new vector layer with the same features of the input layer, "
+                      "but either overwriting an existing attribute or adding an additional attribute." );
+}
+
 QgsFieldCalculatorAlgorithm *QgsFieldCalculatorAlgorithm::createInstance() const
 {
   return new QgsFieldCalculatorAlgorithm();
@@ -138,7 +136,7 @@ QgsFieldCalculatorAlgorithm *QgsFieldCalculatorAlgorithm::createInstance() const
 
 bool QgsFieldCalculatorAlgorithm::prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback )
 {
-  std::unique_ptr< QgsProcessingFeatureSource > source( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
+  std::unique_ptr<QgsProcessingFeatureSource> source( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
 
   if ( !source )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INPUT" ) ) );
@@ -232,7 +230,7 @@ bool QgsFieldCalculatorAlgorithm::prepareAlgorithm( const QVariantMap &parameter
 
   if ( mExpression.hasParserError() )
     throw QgsProcessingException( QObject::tr( "Parser error with formula expression \"%2\": %3" )
-                                  .arg( expressionString, mExpression.parserErrorString() ) );
+                                    .arg( expressionString, mExpression.parserErrorString() ) );
 
   mExpression.prepare( &mExpressionContext );
 
@@ -261,7 +259,7 @@ QgsFeatureList QgsFieldCalculatorAlgorithm::processFeature( const QgsFeature &fe
     if ( mExpression.hasEvalError() )
     {
       throw QgsProcessingException( QObject::tr( "Evaluation error in expression \"%1\": %2" )
-                                    .arg( mExpression.expression(), mExpression.evalErrorString() ) );
+                                      .arg( mExpression.expression(), mExpression.evalErrorString() ) );
     }
 
     attributes[mFieldIdx] = value;
