@@ -45,11 +45,18 @@ void QgsRandomRasterAlgorithmBase::initAlgorithm( const QVariantMap & )
   //add specific parameters
   addAlgorithmParams();
 
-  std::unique_ptr<QgsProcessingParameterString> createOptsParam = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "CREATE_OPTIONS" ), QObject::tr( "Creation options" ), QVariant(), false, true );
+  // backwards compatibility parameter
+  // TODO QGIS 4: remove parameter and related logic
+  auto createOptsParam = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "CREATE_OPTIONS" ), QObject::tr( "Creation options" ), QVariant(), false, true );
   createOptsParam->setMetadata( QVariantMap( { { QStringLiteral( "widget_wrapper" ), QVariantMap( { { QStringLiteral( "widget_type" ), QStringLiteral( "rasteroptions" ) } } ) } } ) );
-  createOptsParam->setFlags( createOptsParam->flags() | Qgis::ProcessingParameterFlag::Advanced );
+  createOptsParam->setFlags( createOptsParam->flags() | Qgis::ProcessingParameterFlag::Hidden );
   addParameter( createOptsParam.release() );
 
+  auto creationOptsParam = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "CREATION_OPTIONS" ), QObject::tr( "Creation options" ), QVariant(), false, true );
+  creationOptsParam->setMetadata( QVariantMap( { { QStringLiteral( "widget_wrapper" ), QVariantMap( { { QStringLiteral( "widget_type" ), QStringLiteral( "rasteroptions" ) } } ) } } ) );
+  creationOptsParam->setFlags( creationOptsParam->flags() | Qgis::ProcessingParameterFlag::Advanced );
+  addParameter( creationOptsParam.release() );
+
   addParameter( new QgsProcessingParameterRasterDestination( QStringLiteral( "OUTPUT" ), QObject::tr( "Output raster" ) ) );
 }
 
@@ -78,23 +85,30 @@ QVariantMap QgsRandomRasterAlgorithmBase::processAlgorithm( const QVariantMap &p
   std::random_device rd {};
   std::mt19937 mersenneTwister { rd() };
 
-  const QString createOptions = parameterAsString( parameters, QStringLiteral( "CREATE_OPTIONS" ), context ).trimmed();
+  QString creationOptions = parameterAsString( parameters, QStringLiteral( "CREATION_OPTIONS" ), context ).trimmed();
+  // handle backwards compatibility parameter CREATE_OPTIONS
+  const QString optionsString = parameterAsString( parameters, QStringLiteral( "CREATE_OPTIONS" ), context );
+  if ( !optionsString.isEmpty() )
+    creationOptions = optionsString;
+
   const QString outputFile = parameterAsOutputLayer( parameters, QStringLiteral( "OUTPUT" ), context );
   const QFileInfo fi( outputFile );
   const QString outputFormat = QgsRasterFileWriter::driverForExtension( fi.suffix() );
 
-  const int rows = std::max( std::ceil( mExtent.height() / mPixelSize ), 1.0 );
-  const int cols = std::max( std::ceil( mExtent.width() / mPixelSize ), 1.0 );
+  // round up width and height to the nearest integer as GDAL does (e.g. in gdal_rasterize)
+  // see https://github.com/qgis/QGIS/issues/43547
+  const int rows = static_cast<int>( 0.5 + mExtent.height() / mPixelSize );
+  const int cols = static_cast<int>( 0.5 + mExtent.width() / mPixelSize );
 
   //build new raster extent based on number of columns and cellsize
   //this prevents output cellsize being calculated too small
   const QgsRectangle rasterExtent = QgsRectangle( mExtent.xMinimum(), mExtent.yMaximum() - ( rows * mPixelSize ), mExtent.xMinimum() + ( cols * mPixelSize ), mExtent.yMaximum() );
 
-  std::unique_ptr<QgsRasterFileWriter> writer = std::make_unique<QgsRasterFileWriter>( outputFile );
+  auto writer = std::make_unique<QgsRasterFileWriter>( outputFile );
   writer->setOutputProviderKey( QStringLiteral( "gdal" ) );
-  if ( !createOptions.isEmpty() )
+  if ( !creationOptions.isEmpty() )
   {
-    writer->setCreateOptions( createOptions.split( '|' ) );
+    writer->setCreationOptions( creationOptions.split( '|' ) );
   }
 
   writer->setOutputFormat( outputFormat );
@@ -199,7 +213,10 @@ QVariantMap QgsRandomRasterAlgorithmBase::processAlgorithm( const QVariantMap &p
       default:
         break;
     }
-    provider->writeBlock( &block, 1, 0, row );
+    if ( !provider->writeBlock( &block, 1, 0, row ) )
+    {
+      throw QgsProcessingException( QObject::tr( "Could not write raster block: %1" ).arg( provider->error().summary() ) );
+    }
     feedback->setProgress( row * step );
   }
 
@@ -228,7 +245,7 @@ QStringList QgsRandomUniformRasterAlgorithm::tags() const
 
 QString QgsRandomUniformRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with random values.\n"
                       "By default, the values will range between the minimum and "
                       "maximum value of the specified output raster type. This can "
@@ -240,6 +257,12 @@ QString QgsRandomUniformRasterAlgorithm::shortHelpString() const
                       "raster type will abort the algorithm." );
 }
 
+QString QgsRandomUniformRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with random values." );
+}
+
 QgsRandomUniformRasterAlgorithm *QgsRandomUniformRasterAlgorithm::createInstance() const
 {
   return new QgsRandomUniformRasterAlgorithm();
@@ -260,11 +283,11 @@ void QgsRandomUniformRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> lowerBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "LOWER_BOUND" ), QStringLiteral( "Lower bound for random number range" ), Qgis::ProcessingNumberParameterType::Double, QVariant(), true );
+  auto lowerBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "LOWER_BOUND" ), QStringLiteral( "Lower bound for random number range" ), Qgis::ProcessingNumberParameterType::Double, QVariant(), true );
   lowerBoundParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( lowerBoundParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> upperBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "UPPER_BOUND" ), QStringLiteral( "Upper bound for random number range" ), Qgis::ProcessingNumberParameterType::Double, QVariant(), true );
+  auto upperBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "UPPER_BOUND" ), QStringLiteral( "Upper bound for random number range" ), Qgis::ProcessingNumberParameterType::Double, QVariant(), true );
   upperBoundParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( upperBoundParameter.release() );
 }
@@ -421,7 +444,7 @@ QStringList QgsRandomBinomialRasterAlgorithm::tags() const
 
 QString QgsRandomBinomialRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with binomially distributed random values.\n"
                       "By default, the values will be chosen given an N of 10 and a probability of 0.5. "
                       "This can be overridden by using the advanced parameter for N and probability. "
@@ -431,6 +454,12 @@ QString QgsRandomBinomialRasterAlgorithm::shortHelpString() const
                       "to floating point." );
 }
 
+QString QgsRandomBinomialRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with binomially distributed random values." );
+}
+
 QgsRandomBinomialRasterAlgorithm *QgsRandomBinomialRasterAlgorithm::createInstance() const
 {
   return new QgsRandomBinomialRasterAlgorithm();
@@ -451,11 +480,11 @@ void QgsRandomBinomialRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> nParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "N" ), QStringLiteral( "N" ), Qgis::ProcessingNumberParameterType::Integer, 10, true, 0 );
+  auto nParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "N" ), QStringLiteral( "N" ), Qgis::ProcessingNumberParameterType::Integer, 10, true, 0 );
   nParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( nParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0 );
+  auto probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0 );
   probabilityParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( probabilityParameter.release() );
 }
@@ -519,7 +548,7 @@ QStringList QgsRandomExponentialRasterAlgorithm::tags() const
 
 QString QgsRandomExponentialRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with exponentially distributed random values.\n"
                       "By default, the values will be chosen given a lambda of 1.0. "
                       "This can be overridden by using the advanced parameter for lambda. "
@@ -527,6 +556,12 @@ QString QgsRandomExponentialRasterAlgorithm::shortHelpString() const
                       "the exponential distribution random values are floating point numbers." );
 }
 
+QString QgsRandomExponentialRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with exponentially distributed random values." );
+}
+
 QgsRandomExponentialRasterAlgorithm *QgsRandomExponentialRasterAlgorithm::createInstance() const
 {
   return new QgsRandomExponentialRasterAlgorithm();
@@ -543,7 +578,7 @@ void QgsRandomExponentialRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> lambdaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "LAMBDA" ), QStringLiteral( "Lambda" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
+  auto lambdaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "LAMBDA" ), QStringLiteral( "Lambda" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
   lambdaParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( lambdaParameter.release() );
 }
@@ -598,7 +633,7 @@ QStringList QgsRandomGammaRasterAlgorithm::tags() const
 
 QString QgsRandomGammaRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with gamma distributed random values.\n"
                       "By default, the values will be chosen given an alpha and beta value of 1.0. "
                       "This can be overridden by using the advanced parameter for alpha and beta. "
@@ -606,6 +641,12 @@ QString QgsRandomGammaRasterAlgorithm::shortHelpString() const
                       "the gamma distribution random values are floating point numbers." );
 }
 
+QString QgsRandomGammaRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with gamma distributed random values." );
+}
+
 QgsRandomGammaRasterAlgorithm *QgsRandomGammaRasterAlgorithm::createInstance() const
 {
   return new QgsRandomGammaRasterAlgorithm();
@@ -622,11 +663,11 @@ void QgsRandomGammaRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> alphaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "ALPHA" ), QStringLiteral( "Alpha" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
+  auto alphaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "ALPHA" ), QStringLiteral( "Alpha" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
   alphaParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( alphaParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> betaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "BETA" ), QStringLiteral( "Beta" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
+  auto betaParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "BETA" ), QStringLiteral( "Beta" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0.000001 );
   betaParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( betaParameter.release() );
 }
@@ -682,7 +723,7 @@ QStringList QgsRandomGeometricRasterAlgorithm::tags() const
 
 QString QgsRandomGeometricRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with geometrically distributed random values.\n"
                       "By default, the values will be chosen given a probability of 0.5. "
                       "This can be overridden by using the advanced parameter for mean "
@@ -692,6 +733,12 @@ QString QgsRandomGeometricRasterAlgorithm::shortHelpString() const
                       "integer values to floating point." );
 }
 
+QString QgsRandomGeometricRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with geometrically distributed random values." );
+}
+
 QgsRandomGeometricRasterAlgorithm *QgsRandomGeometricRasterAlgorithm::createInstance() const
 {
   return new QgsRandomGeometricRasterAlgorithm();
@@ -712,7 +759,7 @@ void QgsRandomGeometricRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0.00001 );
+  auto probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0.00001 );
   probabilityParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( probabilityParameter.release() );
 }
@@ -775,7 +822,7 @@ QStringList QgsRandomNegativeBinomialRasterAlgorithm::tags() const
 
 QString QgsRandomNegativeBinomialRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with negative binomially distributed random values.\n"
                       "By default, the values will be chosen given a distribution parameter k of 10.0 "
                       "and a probability of 0.5. "
@@ -786,6 +833,12 @@ QString QgsRandomNegativeBinomialRasterAlgorithm::shortHelpString() const
                       "integer values to floating point." );
 }
 
+QString QgsRandomNegativeBinomialRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with negative binomially distributed random values." );
+}
+
 QgsRandomNegativeBinomialRasterAlgorithm *QgsRandomNegativeBinomialRasterAlgorithm::createInstance() const
 {
   return new QgsRandomNegativeBinomialRasterAlgorithm();
@@ -806,11 +859,11 @@ void QgsRandomNegativeBinomialRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> kParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "K_PARAMETER" ), QStringLiteral( "Distribution parameter k" ), Qgis::ProcessingNumberParameterType::Integer, 10, true, 0.00001 );
+  auto kParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "K_PARAMETER" ), QStringLiteral( "Distribution parameter k" ), Qgis::ProcessingNumberParameterType::Integer, 10, true, 0.00001 );
   kParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( kParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0.00001 );
+  auto probabilityParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "PROBABILITY" ), QStringLiteral( "Probability" ), Qgis::ProcessingNumberParameterType::Double, 0.5, true, 0.00001 );
   probabilityParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( probabilityParameter.release() );
 }
@@ -874,7 +927,7 @@ QStringList QgsRandomNormalRasterAlgorithm::tags() const
 
 QString QgsRandomNormalRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with normally distributed random values.\n"
                       "By default, the values will be chosen given a mean of 0.0 and "
                       "a standard deviation of 1.0. This can be overridden by "
@@ -883,6 +936,12 @@ QString QgsRandomNormalRasterAlgorithm::shortHelpString() const
                       "as the normal distribution random values are floating point numbers." );
 }
 
+QString QgsRandomNormalRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with normally distributed random values." );
+}
+
 QgsRandomNormalRasterAlgorithm *QgsRandomNormalRasterAlgorithm::createInstance() const
 {
   return new QgsRandomNormalRasterAlgorithm();
@@ -898,11 +957,11 @@ void QgsRandomNormalRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> meanParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "MEAN" ), QStringLiteral( "Mean of normal distribution" ), Qgis::ProcessingNumberParameterType::Double, 0, true );
+  auto meanParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "MEAN" ), QStringLiteral( "Mean of normal distribution" ), Qgis::ProcessingNumberParameterType::Double, 0, true );
   meanParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( meanParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> stdevParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "STDDEV" ), QStringLiteral( "Standard deviation of normal distribution" ), Qgis::ProcessingNumberParameterType::Double, 1, true, 0 );
+  auto stdevParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "STDDEV" ), QStringLiteral( "Standard deviation of normal distribution" ), Qgis::ProcessingNumberParameterType::Double, 1, true, 0 );
   stdevParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( stdevParameter.release() );
 }
@@ -958,7 +1017,7 @@ QStringList QgsRandomPoissonRasterAlgorithm::tags() const
 
 QString QgsRandomPoissonRasterAlgorithm::shortHelpString() const
 {
-  return QObject::tr( "Generates a raster layer for given extent and cell size "
+  return QObject::tr( "This algorithm generates a raster layer for a given extent and cell size "
                       "filled with poisson distributed random values.\n"
                       "By default, the values will be chosen given a mean of 1.0. "
                       "This can be overridden by using the advanced parameter for mean "
@@ -967,6 +1026,12 @@ QString QgsRandomPoissonRasterAlgorithm::shortHelpString() const
                       "A floating point raster will represent a cast of integer values to floating point." );
 }
 
+QString QgsRandomPoissonRasterAlgorithm::shortDescription() const
+{
+  return QObject::tr( "Generates a raster layer for a given extent and cell size "
+                      "filled with poisson distributed random values." );
+}
+
 QgsRandomPoissonRasterAlgorithm *QgsRandomPoissonRasterAlgorithm::createInstance() const
 {
   return new QgsRandomPoissonRasterAlgorithm();
@@ -987,7 +1052,7 @@ void QgsRandomPoissonRasterAlgorithm::addAlgorithmParams()
   rasterTypeParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( rasterTypeParameter.release() );
 
-  std::unique_ptr<QgsProcessingParameterNumber> upperBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "MEAN" ), QStringLiteral( "Mean" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0 );
+  auto upperBoundParameter = std::make_unique<QgsProcessingParameterNumber>( QStringLiteral( "MEAN" ), QStringLiteral( "Mean" ), Qgis::ProcessingNumberParameterType::Double, 1.0, true, 0 );
   upperBoundParameter->setFlags( Qgis::ProcessingParameterFlag::Advanced );
   addParameter( upperBoundParameter.release() );
 }
