@@ -15,6 +15,7 @@
 
 #include "qgscolorutils.h"
 #include "qgsprojectstylesettings.h"
+#include "moc_qgsprojectstylesettings.cpp"
 #include "qgis.h"
 #include "qgsproject.h"
 #include "qgssymbol.h"
@@ -223,7 +224,7 @@ bool QgsProjectStyleSettings::readXml( const QDomElement &element, const QgsRead
   if ( !elem.isNull() )
   {
     QDomElement symbolElem = elem.firstChildElement( QStringLiteral( "symbol" ) );
-    mDefaultMarkerSymbol.reset( !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsMarkerSymbol>( symbolElem, context ) : nullptr );
+    mDefaultMarkerSymbol = !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsMarkerSymbol>( symbolElem, context ) : nullptr;
   }
   else
   {
@@ -234,7 +235,7 @@ bool QgsProjectStyleSettings::readXml( const QDomElement &element, const QgsRead
   if ( !elem.isNull() )
   {
     QDomElement symbolElem = elem.firstChildElement( QStringLiteral( "symbol" ) );
-    mDefaultLineSymbol.reset( !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsLineSymbol>( symbolElem, context ) : nullptr );
+    mDefaultLineSymbol = !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsLineSymbol>( symbolElem, context ) : nullptr;
   }
   else
   {
@@ -245,7 +246,7 @@ bool QgsProjectStyleSettings::readXml( const QDomElement &element, const QgsRead
   if ( !elem.isNull() )
   {
     QDomElement symbolElem = elem.firstChildElement( QStringLiteral( "symbol" ) );
-    mDefaultFillSymbol.reset( !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsFillSymbol>( symbolElem, context ) : nullptr );
+    mDefaultFillSymbol = !symbolElem.isNull() ? QgsSymbolLayerUtils::loadSymbol<QgsFillSymbol>( symbolElem, context ) : nullptr;
   }
   else
   {
@@ -253,7 +254,7 @@ bool QgsProjectStyleSettings::readXml( const QDomElement &element, const QgsRead
   }
 
   elem = element.firstChildElement( QStringLiteral( "colorramp" ) );
-  mDefaultColorRamp.reset( !elem.isNull() ? QgsSymbolLayerUtils::loadColorRamp( elem ) : nullptr );
+  mDefaultColorRamp = !elem.isNull() ? QgsSymbolLayerUtils::loadColorRamp( elem ) : nullptr;
 
   elem = element.firstChildElement( QStringLiteral( "text-style" ) );
   if ( !elem.isNull() )
