@@ -47,10 +47,6 @@ class CORE_EXPORT QgsTextFormat
      */
     QgsTextFormat();
 
-    /**
-     * Copy constructor.
-     * \param other source QgsTextFormat
-     */
     QgsTextFormat( const QgsTextFormat &other );
 
     QgsTextFormat &operator=( const QgsTextFormat &other );
@@ -178,7 +174,7 @@ class CORE_EXPORT QgsTextFormat
      * units and map unit scale) for a specified render context.
      * \param context destination render context
      * \param scaleFactor optional font size scaling factor. It is recommended to set this to
-     * QgsTextRenderer::FONT_WORKAROUND_SCALE and then manually scale painter devices or calculations
+     * QgsTextRenderer::calculateScaleFactorForFormat() and then manually scale painter devices or calculations
      * based on the resultant font metrics. Failure to do so will result in poor quality text rendering
      * at small font sizes.
      * \param isZeroSize will be set to true if the font is scaled down to a near 0 size, and nothing should be rendered. Not available in Python bindings.
@@ -466,6 +462,9 @@ class CORE_EXPORT QgsTextFormat
     /**
      * Returns the distance for tab stops.
      *
+     * \note This value will be ignored if tabPositions() is non-empty.
+     *
+     * \see tabPositions()
      * \see tabStopDistanceUnit()
      * \see setTabStopDistance()
      *
@@ -474,8 +473,13 @@ class CORE_EXPORT QgsTextFormat
     double tabStopDistance() const;
 
     /**
-     * Sets the \a distance for tab stops. The units are specified using setTabStopDistanceUnit().
+     * Sets the \a distance for tab stops.
      *
+     * The units are specified using setTabStopDistanceUnit().
+     *
+     * \note This value will be ignored if tabPositions() is non-empty.
+     *
+     * \see tabPositions()
      * \see tabStopDistance()
      * \see setTabStopDistanceUnit()
      *
@@ -483,10 +487,89 @@ class CORE_EXPORT QgsTextFormat
      */
     void setTabStopDistance( double distance );
 
+    /**
+     * \ingroup core
+     * \brief Defines a tab position for a text format.
+     * \since QGIS 3.42
+     */
+    class CORE_EXPORT Tab
+    {
+      public:
+
+        /**
+         * Constructor for a Tab at the specified \a position.
+         */
+        explicit Tab( double position );
+
+        /**
+         * Sets the tab position.
+         *
+         * \see position()
+         */
+        void setPosition( double position ) { mPosition = position; }
+
+        /**
+         * Returns the tab position.
+         *
+         * \see setPosition()
+         */
+        double position() const { return mPosition; }
+
+        bool operator==( const QgsTextFormat::Tab &other ) const
+        {
+          return qgsDoubleNear( mPosition, other.mPosition );
+        }
+
+#ifdef SIP_RUN
+        SIP_PYOBJECT __repr__();
+        % MethodCode
+        const QString str = QStringLiteral( "<QgsTextFormat.Tab: %1>" ).arg( sipCpp->position() );
+        sipRes = PyUnicode_FromString( str.toUtf8().constData() );
+        % End
+#endif
+
+      private:
+
+        double mPosition = 0;
+
+    };
+
+    /**
+     * Returns the list of tab positions for tab stops.
+     *
+     * The units are specified using tabStopDistanceUnit().
+     *
+     * \note If non-empty, this list overrides any distance defined by tabStopDistance().
+     *
+     * \see setTabPositions()
+     * \see tabStopDistance()
+     * \see tabStopDistanceUnit()
+     * \see setTabStopDistance()
+     *
+     * \since QGIS 3.42
+     */
+    QList< QgsTextFormat::Tab > tabPositions() const;
+
+    /**
+     * Sets the list of tab \a positions for tab stops.
+     *
+     * The units are specified using setTabStopDistanceUnit().
+     *
+     * \note If non-empty, this list overrides any distance defined by setTabStopDistance().
+     *
+     * \see tabPositions()
+     * \see setTabStopDistance()
+     * \see setTabStopDistanceUnit()
+     *
+     * \since QGIS 3.42
+     */
+    void setTabPositions( const QList< QgsTextFormat::Tab > &positions );
+
     /**
      * Returns the units for the tab stop distance.
      *
      * \see tabStopDistance()
+     * \see tabPositions()
      * \see setTabStopDistanceUnit()
      *
      * \since QGIS 3.38
@@ -497,6 +580,7 @@ class CORE_EXPORT QgsTextFormat
      * Sets the \a unit used for the tab stop distance.
      *
      * \see setTabStopDistance()
+     * \see setTabPositions()
      * \see tabStopDistanceUnit()
      *
      * \since QGIS 3.38
@@ -657,6 +741,15 @@ class CORE_EXPORT QgsTextFormat
      */
     bool containsAdvancedEffects() const;
 
+    /**
+     * Returns TRUE if any component of the font format requires a non-default composition mode.
+     *
+     * The default composition mode is QPainter::CompositionMode_SourceOver.
+     *
+     * \since QGIS 3.44
+     */
+    bool hasNonDefaultCompositionMode() const;
+
     /**
      * Returns TRUE if the specified font was found on the system, or FALSE
      * if the font was not found and a replacement was used instead.
