@@ -32,24 +32,6 @@
 #include "qgsauthmanager.h"
 #include "qgslogger.h"
 
-
-static void setItemBold_( QTreeWidgetItem *item )
-{
-  item->setFirstColumnSpanned( true );
-  QFont secf( item->font( 0 ) );
-  secf.setBold( true );
-  item->setFont( 0, secf );
-}
-
-static void removeChildren_( QTreeWidgetItem *item )
-{
-  const auto constTakeChildren = item->takeChildren();
-  for ( QTreeWidgetItem *child : constTakeChildren )
-  {
-    delete child;
-  }
-}
-
 QgsAuthCertInfo::QgsAuthCertInfo( const QSslCertificate &cert, bool manageCertTrust, QWidget *parent, const QList<QSslCertificate> &connectionCAs )
   : QWidget( parent )
   , mConnectionCAs( connectionCAs )
@@ -323,7 +305,7 @@ void QgsAuthCertInfo::setUpCertDetailsTree()
     QStringList( tr( "General" ) ),
     static_cast<int>( DetailsSection )
   );
-  setItemBold_( mSecGeneral );
+  QgsAuthGuiUtils::setItemBold( mSecGeneral );
   mSecGeneral->setFirstColumnSpanned( true );
   mSecGeneral->setFlags( Qt::ItemIsEnabled );
   mSecGeneral->setExpanded( true );
@@ -334,7 +316,7 @@ void QgsAuthCertInfo::setUpCertDetailsTree()
     QStringList( tr( "Details" ) ),
     static_cast<int>( DetailsSection )
   );
-  setItemBold_( mSecDetails );
+  QgsAuthGuiUtils::setItemBold( mSecDetails );
   mSecDetails->setFirstColumnSpanned( true );
   mSecDetails->setFlags( Qt::ItemIsEnabled );
   mSecDetails->setExpanded( false );
@@ -352,7 +334,7 @@ void QgsAuthCertInfo::setUpCertDetailsTree()
     QStringList( tr( "PEM Text" ) ),
     static_cast<int>( DetailsSection )
   );
-  setItemBold_( mSecPemText );
+  QgsAuthGuiUtils::setItemBold( mSecPemText );
   mSecPemText->setFirstColumnSpanned( true );
   mSecPemText->setFlags( Qt::ItemIsEnabled );
   mSecPemText->setExpanded( false );
@@ -447,7 +429,7 @@ void QgsAuthCertInfo::addFieldItem( QTreeWidgetItem *parent, const QString &fiel
 
 void QgsAuthCertInfo::populateInfoGeneralSection()
 {
-  removeChildren_( mSecGeneral );
+  QgsAuthGuiUtils::removeChildren( mSecGeneral );
 
   if ( mCurrentQCert.isNull() )
   {
@@ -506,11 +488,11 @@ void QgsAuthCertInfo::populateInfoGeneralSection()
 
 void QgsAuthCertInfo::populateInfoDetailsSection()
 {
-  removeChildren_( mGrpSubj );
-  removeChildren_( mGrpIssu );
-  removeChildren_( mGrpCert );
-  removeChildren_( mGrpPkey );
-  removeChildren_( mGrpExts );
+  QgsAuthGuiUtils::removeChildren( mGrpSubj );
+  QgsAuthGuiUtils::removeChildren( mGrpIssu );
+  QgsAuthGuiUtils::removeChildren( mGrpCert );
+  QgsAuthGuiUtils::removeChildren( mGrpPkey );
+  QgsAuthGuiUtils::removeChildren( mGrpExts );
 
   if ( mCurrentQCert.isNull() )
     return;
@@ -692,7 +674,7 @@ void QgsAuthCertInfo::populateInfoDetailsSection()
 
 void QgsAuthCertInfo::populateInfoPemTextSection()
 {
-  removeChildren_( mSecPemText );
+  QgsAuthGuiUtils::removeChildren( mSecPemText );
 
   if ( mCurrentQCert.isNull() )
     return;
