@@ -24,6 +24,7 @@
 #include "qgscodeeditorhistorydialog.h"
 #include "qgsstringutils.h"
 #include "qgsfontutils.h"
+#include "qgssettingsentryimpl.h"
 
 #include <QLabel>
 #include <QWidget>
@@ -38,6 +39,11 @@
 #include <QMessageBox>
 #include "Qsci/qscilexer.h"
 
+///@cond PRIVATE
+const QgsSettingsEntryBool *QgsCodeEditor::settingContextHelpHover = new QgsSettingsEntryBool( QStringLiteral( "context-help-hover" ), sTreeCodeEditor, false, QStringLiteral( "Whether the context help should works on hovered words" ) );
+///@endcond PRIVATE
+
+
 QMap<QgsCodeEditorColorScheme::ColorRole, QString> QgsCodeEditor::sColorRoleToSettingsKey {
   { QgsCodeEditorColorScheme::ColorRole::Default, QStringLiteral( "defaultFontColor" ) },
   { QgsCodeEditorColorScheme::ColorRole::Keyword, QStringLiteral( "keywordFontColor" ) },
@@ -143,6 +149,12 @@ QgsCodeEditor::QgsCodeEditor( QWidget *parent, const QString &title, bool foldin
 #if QSCINTILLA_VERSION < 0x020d03
   installEventFilter( this );
 #endif
+
+  mLastEditTimer = new QTimer( this );
+  mLastEditTimer->setSingleShot( true );
+  mLastEditTimer->setInterval( 1000 );
+  connect( mLastEditTimer, &QTimer::timeout, this, &QgsCodeEditor::onLastEditTimeout );
+  connect( this, &QgsCodeEditor::textChanged, mLastEditTimer, qOverload<>( &QTimer::start ) );
 }
 
 // Workaround a bug in QScintilla 2.8.X
@@ -171,6 +183,7 @@ void QgsCodeEditor::focusOutEvent( QFocusEvent *event )
   {
     QsciScintilla::focusOutEvent( event );
   }
+  onLastEditTimeout();
 }
 
 // This workaround a likely bug in QScintilla. The ESC key should not be consumned
@@ -191,6 +204,29 @@ void QgsCodeEditor::keyPressEvent( QKeyEvent *event )
     return;
   }
 
+  if ( event->key() == Qt::Key_F1 )
+  {
+    // Check if some text is selected
+    QString text = selectedText();
+
+    // Check if mouse is hovering over a word
+    if ( text.isEmpty() && settingContextHelpHover->value() )
+    {
+      text = wordAtPoint( mapFromGlobal( QCursor::pos() ) );
+    }
+
+    // Otherwise, check if there is a word at the current text cursor position
+    if ( text.isEmpty() )
+    {
+      int line, index;
+      getCursorPosition( &line, &index );
+      text = wordAtLineIndex( line, index );
+    }
+    emit helpRequested( text );
+    return;
+  }
+
+
   if ( mMode == QgsCodeEditor::Mode::CommandInput )
   {
     switch ( event->key() )
@@ -282,7 +318,7 @@ void QgsCodeEditor::contextMenuEvent( QContextMenuEvent *event )
       {
         QAction *toggleCommentAction = new QAction( tr( "Toggle Comment" ), menu );
         toggleCommentAction->setShortcut( QStringLiteral( "Ctrl+:" ) );
-        toggleCommentAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "console/iconCommentEditorConsole.svg" ) ) );
+        toggleCommentAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "console/iconCommentEditorConsole.svg" ), palette().color( QPalette::ColorRole::WindowText ) ) );
         toggleCommentAction->setEnabled( !isReadOnly() );
         connect( toggleCommentAction, &QAction::triggered, this, &QgsCodeEditor::toggleComment );
         menu->addAction( toggleCommentAction );
@@ -323,6 +359,7 @@ void QgsCodeEditor::contextMenuEvent( QContextMenuEvent *event )
   }
 }
 
+
 bool QgsCodeEditor::eventFilter( QObject *watched, QEvent *event )
 {
 #if QSCINTILLA_VERSION < 0x020d03
@@ -424,6 +461,12 @@ void QgsCodeEditor::runPostLexerConfigurationTasks()
   }
 }
 
+void QgsCodeEditor::onLastEditTimeout()
+{
+  mLastEditTimer->stop();
+  emit editingTimeout();
+}
+
 void QgsCodeEditor::setSciWidget()
 {
   const QFont font = lexerFont();
@@ -788,6 +831,141 @@ void QgsCodeEditor::toggleComment()
 {
 }
 
+void QgsCodeEditor::toggleLineComments( const QString &commentPrefix )
+{
+  if ( isReadOnly() )
+  {
+    return;
+  }
+
+  beginUndoAction();
+  int startLine, startPos, endLine, endPos;
+  if ( hasSelectedText() )
+  {
+    getSelection( &startLine, &startPos, &endLine, &endPos );
+  }
+  else
+  {
+    getCursorPosition( &startLine, &startPos );
+    endLine = startLine;
+    endPos = startPos;
+  }
+
+  // Check comment state and minimum indentation for each selected line
+  bool allEmpty = true;
+  bool allCommented = true;
+  int minIndentation = -1;
+  for ( int line = startLine; line <= endLine; line++ )
+  {
+    const QString stripped = text( line ).trimmed();
+    if ( !stripped.isEmpty() )
+    {
+      allEmpty = false;
+      if ( !stripped.startsWith( commentPrefix ) )
+      {
+        allCommented = false;
+      }
+      if ( minIndentation == -1 || minIndentation > indentation( line ) )
+      {
+        minIndentation = indentation( line );
+      }
+    }
+  }
+
+  // Special case, only empty lines
+  if ( allEmpty )
+  {
+    return;
+  }
+
+  // Selection shift to keep the same selected text after the prefix is added/removed
+  int delta = 0;
+
+  const int prefixLength = static_cast<int>( commentPrefix.length() );
+
+  const bool startLineEmpty = ( text( startLine ).trimmed().isEmpty() );
+  const bool endLineEmpty = ( text( endLine ).trimmed().isEmpty() );
+
+  for ( int line = startLine; line <= endLine; line++ )
+  {
+    const QString stripped = text( line ).trimmed();
+
+    // Empty line
+    if ( stripped.isEmpty() )
+    {
+      continue;
+    }
+
+    if ( !allCommented )
+    {
+      insertAt( commentPrefix + ' ', line, minIndentation );
+      delta = -( prefixLength + 1 );
+    }
+    else
+    {
+      if ( !stripped.startsWith( commentPrefix ) )
+      {
+        continue;
+      }
+      if ( stripped.startsWith( commentPrefix + ' ' ) )
+      {
+        delta = prefixLength + 1;
+      }
+      else
+      {
+        delta = prefixLength;
+      }
+      setSelection( line, indentation( line ), line, indentation( line ) + delta );
+      removeSelectedText();
+    }
+  }
+
+  endUndoAction();
+  setSelection( startLine, startPos - ( startLineEmpty ? 0 : delta ), endLine, endPos - ( endLineEmpty ? 0 : delta ) );
+}
+
+void QgsCodeEditor::adjustScrollWidth()
+{
+  // A zero width would make setScrollWidth crash
+  long maxWidth = 10;
+
+  // Get the number of lines
+  int lineCount = lines();
+
+  // Loop through all the lines to get the longest one
+  for ( int line = 0; line < lineCount; line++ )
+  {
+    // Get the linear position at the end of the current line
+    const long endLine = SendScintilla( SCI_GETLINEENDPOSITION, line );
+    // Get the x coordinates of the end of the line
+    const long x = SendScintilla( SCI_POINTXFROMPOSITION, 0, endLine );
+    maxWidth = std::max( maxWidth, x );
+  }
+
+  // Use the longest line width as the new scroll width
+  setScrollWidth( static_cast<int>( maxWidth ) );
+}
+
+void QgsCodeEditor::setText( const QString &text )
+{
+  disconnect( this, &QgsCodeEditor::textChanged, mLastEditTimer, qOverload<>( &QTimer::start ) );
+  QsciScintilla::setText( text );
+  connect( this, &QgsCodeEditor::textChanged, mLastEditTimer, qOverload<>( &QTimer::start ) );
+  onLastEditTimeout();
+  adjustScrollWidth();
+}
+
+int QgsCodeEditor::editingTimeoutInterval() const
+{
+  return mLastEditTimer->interval();
+}
+
+void QgsCodeEditor::setEditingTimeoutInterval( int timeout )
+{
+  mLastEditTimer->setInterval( timeout );
+}
+
+
 QStringList QgsCodeEditor::history() const
 {
   return mHistory;
