@@ -16,12 +16,14 @@
  ***************************************************************************/
 
 #include "qgsgeopackageitemguiprovider.h"
+#include "moc_qgsgeopackageitemguiprovider.cpp"
 ///@cond PRIVATE
 
 #include <QAction>
 #include <QMenu>
 #include <QString>
 #include <QMessageBox>
+#include <QFileDialog>
 
 #include "qgsvectorlayer.h"
 #include "qgsrasterlayer.h"
@@ -40,12 +42,13 @@
 #include "qgsmessagebar.h"
 #include "qgsprovidermetadata.h"
 #include "qgsogrproviderutils.h"
+#include "qgsfileutils.h"
+#include "qgsdbimportvectorlayerdialog.h"
+#include "qgsdataitemguiproviderutils.h"
 
-void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu *menu,
-    const QList<QgsDataItem *> &selectedItems,
-    QgsDataItemGuiContext context )
+void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu *menu, const QList<QgsDataItem *> &selectedItems, QgsDataItemGuiContext context )
 {
-  if ( QgsGeoPackageVectorLayerItem *layerItem = qobject_cast< QgsGeoPackageVectorLayerItem * >( item ) )
+  if ( QgsGeoPackageVectorLayerItem *layerItem = qobject_cast<QgsGeoPackageVectorLayerItem *>( item ) )
   {
     // Check capabilities
     // (We only show the rename action when the user has a single layer selected -- it doesn't work on multi-layers at once)
@@ -57,9 +60,8 @@ void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu
       const QString uri = layerItem->uri();
       const QString providerKey = layerItem->providerKey();
       const QStringList tableNames = layerItem->tableNames();
-      const QPointer< QgsDataItem > itemPointer( layerItem );
-      connect( actionRenameLayer, &QAction::triggered, this, [this, uri, providerKey, tableNames, itemPointer, context ]
-      {
+      const QPointer<QgsDataItem> itemPointer( layerItem );
+      connect( actionRenameLayer, &QAction::triggered, this, [this, uri, providerKey, tableNames, itemPointer, context] {
         renameVectorLayer( uri, providerKey, tableNames, itemPointer, context );
       } );
       manageLayerMenu->addAction( actionRenameLayer );
@@ -68,23 +70,33 @@ void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu
     }
   }
 
-  if ( QgsGeoPackageRootItem *rootItem = qobject_cast< QgsGeoPackageRootItem * >( item ) )
+  if ( QgsGeoPackageRootItem *rootItem = qobject_cast<QgsGeoPackageRootItem *>( item ) )
   {
     QAction *actionNew = new QAction( tr( "New Connection…" ), menu );
     connect( actionNew, &QAction::triggered, rootItem, &QgsGeoPackageRootItem::newConnection );
     menu->addAction( actionNew );
 
+    const QPointer<QgsGeoPackageRootItem> rootItemPointer( rootItem );
+
     QAction *actionCreateDatabase = new QAction( tr( "Create Database…" ), menu );
-    const QPointer< QgsGeoPackageRootItem > rootItemPointer( rootItem );
-    connect( actionCreateDatabase, &QAction::triggered, this, [this, rootItemPointer ]
-    {
+    connect( actionCreateDatabase, &QAction::triggered, this, [this, rootItemPointer] {
       createDatabase( rootItemPointer );
     } );
     menu->addAction( actionCreateDatabase );
+
+    QAction *actionCreateDatabaseAndLayer = new QAction( tr( "Create Database and Layer…" ), menu );
+    connect( actionCreateDatabaseAndLayer, &QAction::triggered, this, [this, rootItemPointer] {
+      createDatabaseAndLayer( rootItemPointer );
+    } );
+    menu->addAction( actionCreateDatabaseAndLayer );
   }
 
-  if ( QgsGeoPackageCollectionItem *collectionItem = qobject_cast< QgsGeoPackageCollectionItem * >( item ) )
+  if ( QgsGeoPackageCollectionItem *collectionItem = qobject_cast<QgsGeoPackageCollectionItem *>( item ) )
   {
+    QAction *importVectorAction = new QAction( QObject::tr( "Import Vector Layer…" ), menu );
+    menu->addAction( importVectorAction );
+    QObject::connect( importVectorAction, &QAction::triggered, item, [collectionItem, context, this] { handleImportVector( collectionItem, context ); } );
+
     if ( !( item->capabilities2() & Qgis::BrowserItemCapability::ItemRepresentsFile ) )
     {
       // add a refresh action, but ONLY if the collection item isn't representing a file
@@ -107,28 +119,24 @@ void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu
 
     if ( QgsOgrDbConnection::connectionList( QStringLiteral( "GPKG" ) ).contains( collectionItem->name() ) )
     {
-      QList< QgsGeoPackageCollectionItem * > connectionItems = QgsDataItem::filteredItems<QgsGeoPackageCollectionItem>( selectedItems );
-      connectionItems.erase( std::remove_if( connectionItems.begin(), connectionItems.end(), []( QgsGeoPackageCollectionItem * connectionItem )
-      {
-        return !QgsOgrDbConnection::connectionList( QStringLiteral( "GPKG" ) ).contains( connectionItem->name() );
-      } ), connectionItems.end() );
+      QList<QgsGeoPackageCollectionItem *> connectionItems = QgsDataItem::filteredItems<QgsGeoPackageCollectionItem>( selectedItems );
+      connectionItems.erase( std::remove_if( connectionItems.begin(), connectionItems.end(), []( QgsGeoPackageCollectionItem *connectionItem ) {
+                               return !QgsOgrDbConnection::connectionList( QStringLiteral( "GPKG" ) ).contains( connectionItem->name() );
+                             } ),
+                             connectionItems.end() );
 
       QAction *actionDeleteConnection = new QAction( connectionItems.size() > 1 ? tr( "Remove Connections…" ) : tr( "Remove Connection…" ), menu );
       if ( connectionItems.size() > 1 )
       {
-        connect( actionDeleteConnection, &QAction::triggered, this, [connectionItems]
-        {
+        connect( actionDeleteConnection, &QAction::triggered, this, [connectionItems] {
           QStringList connectionNames;
           connectionNames.reserve( connectionItems.size() );
           for ( QgsGeoPackageCollectionItem *item : connectionItems )
           {
             connectionNames << item->name();
           }
-          QPointer< QgsDataItem > firstParent( connectionItems.at( 0 )->parent() );
-          if ( QMessageBox::question( nullptr,
-                                      QObject::tr( "Remove Connections" ),
-                                      QObject::tr( "Are you sure you want to remove all %1 selected connections?" ).arg( connectionItems.size() ),
-                                      QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+          QPointer<QgsDataItem> firstParent( connectionItems.at( 0 )->parent() );
+          if ( QMessageBox::question( nullptr, QObject::tr( "Remove Connections" ), QObject::tr( "Are you sure you want to remove all %1 selected connections?" ).arg( connectionItems.size() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
             return;
 
           for ( const QString &connectionName : std::as_const( connectionNames ) )
@@ -159,7 +167,7 @@ void QgsGeoPackageItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu
 
 bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &newName, QgsDataItemGuiContext context )
 {
-  if ( QgsGeoPackageVectorLayerItem *layerItem = qobject_cast< QgsGeoPackageVectorLayerItem * >( item ) )
+  if ( QgsGeoPackageVectorLayerItem *layerItem = qobject_cast<QgsGeoPackageVectorLayerItem *>( item ) )
   {
     // Checks that name does not exist yet
     if ( layerItem->tableNames().contains( newName ) )
@@ -168,15 +176,18 @@ bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &new
     }
     // Check if the layer(s) are in the registry
     const QList<QgsMapLayer *> layersList( layerItem->layersInProject() );
-    if ( ! layersList.isEmpty( ) )
+    if ( !layersList.isEmpty() )
     {
       if ( QMessageBox::question( nullptr, QObject::tr( "Rename Layer" ), QObject::tr( "The layer <b>%1</b> is loaded in the current project with name <b>%2</b>,"
-                                  " do you want to remove it from the project and rename it?" ).arg( layerItem->name(), layersList.at( 0 )->name() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+                                                                                       " do you want to remove it from the project and rename it?" )
+                                                                            .arg( layerItem->name(), layersList.at( 0 )->name() ),
+                                  QMessageBox::Yes | QMessageBox::No, QMessageBox::No )
+           != QMessageBox::Yes )
       {
         return true;
       }
     }
-    if ( ! layersList.isEmpty() )
+    if ( !layersList.isEmpty() )
     {
       QgsProject::instance()->removeMapLayers( layersList );
     }
@@ -190,15 +201,18 @@ bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &new
     else
     {
       const QList<QgsMapLayer *> layersList( layerItem->layersInProject() );
-      if ( ! layersList.isEmpty( ) )
+      if ( !layersList.isEmpty() )
       {
         if ( QMessageBox::question( nullptr, QObject::tr( "Rename Layer" ), QObject::tr( "The layer <b>%1</b> exists in the current project <b>%2</b>,"
-                                    " do you want to remove it from the project and rename it?" ).arg( layerItem->name(), layersList.at( 0 )->name() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+                                                                                         " do you want to remove it from the project and rename it?" )
+                                                                              .arg( layerItem->name(), layersList.at( 0 )->name() ),
+                                    QMessageBox::Yes | QMessageBox::No, QMessageBox::No )
+             != QMessageBox::Yes )
         {
           return true;
         }
       }
-      if ( ! layersList.isEmpty() )
+      if ( !layersList.isEmpty() )
       {
         QgsProject::instance()->removeMapLayers( layersList );
       }
@@ -207,7 +221,7 @@ bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &new
       QgsProviderMetadata *md { QgsProviderRegistry::instance()->providerMetadata( QStringLiteral( "ogr" ) ) };
       std::unique_ptr<QgsGeoPackageProviderConnection> conn( static_cast<QgsGeoPackageProviderConnection *>( md->createConnection( layerItem->collection()->path(), QVariantMap() ) ) );
       const QString oldName = parts.value( QStringLiteral( "layerName" ) ).toString();
-      if ( ! conn->tableExists( QString(), oldName ) )
+      if ( !conn->tableExists( QString(), oldName ) )
       {
         errCause = QObject::tr( "There was an error retrieving the connection %1!" ).arg( layerItem->collection()->name() );
       }
@@ -228,7 +242,7 @@ bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &new
       }
     }
 
-    if ( ! errCause.isEmpty() )
+    if ( !errCause.isEmpty() )
     {
       notify( QObject::tr( "Error renaming layer" ), errCause, context, Qgis::MessageLevel::Critical );
     }
@@ -243,8 +257,7 @@ bool QgsGeoPackageItemGuiProvider::rename( QgsDataItem *item, const QString &new
   return false;
 }
 
-void QgsGeoPackageItemGuiProvider::renameVectorLayer( const QString &uri, const QString &key, const QStringList &tableNames,
-    const QPointer< QgsDataItem > &item, QgsDataItemGuiContext context )
+void QgsGeoPackageItemGuiProvider::renameVectorLayer( const QString &uri, const QString &key, const QStringList &tableNames, const QPointer<QgsDataItem> &item, QgsDataItemGuiContext context )
 {
   // Get layer name from layer URI
   QVariantMap pieces( QgsProviderRegistry::instance()->decodeUri( key, uri ) );
@@ -268,27 +281,27 @@ void QgsGeoPackageItemGuiProvider::renameVectorLayer( const QString &uri, const
 
 bool QgsGeoPackageItemGuiProvider::deleteLayer( QgsLayerItem *layerItem, QgsDataItemGuiContext context )
 {
-  if ( QgsGeoPackageAbstractLayerItem *item = qobject_cast< QgsGeoPackageAbstractLayerItem * >( layerItem ) )
+  if ( QgsGeoPackageAbstractLayerItem *item = qobject_cast<QgsGeoPackageAbstractLayerItem *>( layerItem ) )
   {
     // Check if the layer(s) are in the registry
-    const QList<QgsMapLayer *> layersList( item->layersInProject( ) );
-    if ( ! layersList.isEmpty( ) )
+    const QList<QgsMapLayer *> layersList( item->layersInProject() );
+    if ( !layersList.isEmpty() )
     {
       if ( QMessageBox::question( nullptr, QObject::tr( "Delete Layer" ), QObject::tr( "The layer <b>%1</b> exists in the current project <b>%2</b>,"
-                                  " do you want to remove it from the project and delete it?" ).arg( item->name(),
-                                      layersList.at( 0 )->name() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+                                                                                       " do you want to remove it from the project and delete it?" )
+                                                                            .arg( item->name(), layersList.at( 0 )->name() ),
+                                  QMessageBox::Yes | QMessageBox::No, QMessageBox::No )
+           != QMessageBox::Yes )
       {
         return false;
       }
     }
-    else if ( QMessageBox::question( nullptr, QObject::tr( "Delete Layer" ),
-                                     QObject::tr( "Are you sure you want to delete layer <b>%1</b> from GeoPackage?" ).arg( item->name() ),
-                                     QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+    else if ( QMessageBox::question( nullptr, QObject::tr( "Delete Layer" ), QObject::tr( "Are you sure you want to delete layer <b>%1</b> from GeoPackage?" ).arg( item->name() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
     {
       return false;
     }
 
-    if ( ! layersList.isEmpty() )
+    if ( !layersList.isEmpty() )
     {
       QgsProject::instance()->removeMapLayers( layersList );
     }
@@ -301,12 +314,14 @@ bool QgsGeoPackageItemGuiProvider::deleteLayer( QgsLayerItem *layerItem, QgsData
     }
     else
     {
-
       QgsGeoPackageConnectionItem *connectionParentItem = qobject_cast<QgsGeoPackageConnectionItem *>( item->parent() );
       if ( connectionParentItem )
       {
         if ( QMessageBox::question( nullptr, QObject::tr( "Delete Layer" ), QObject::tr( "The layer <b>%1</b> was successfully deleted."
-                                    " Compact database (VACUUM) <b>%2</b> now?" ).arg( item->name(), connectionParentItem->name() ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) == QMessageBox::Yes )
+                                                                                         " Compact database (VACUUM) <b>%2</b> now?" )
+                                                                              .arg( item->name(), connectionParentItem->name() ),
+                                    QMessageBox::Yes | QMessageBox::No, QMessageBox::No )
+             == QMessageBox::Yes )
         {
           vacuumGeoPackageDbAction( connectionParentItem->path(), connectionParentItem->name(), context );
         }
@@ -343,12 +358,49 @@ void QgsGeoPackageItemGuiProvider::vacuumGeoPackageDbAction( const QString &path
   }
 }
 
-void QgsGeoPackageItemGuiProvider::createDatabase( const QPointer< QgsGeoPackageRootItem > &item )
+void QgsGeoPackageItemGuiProvider::createDatabase( const QPointer<QgsGeoPackageRootItem> &item )
+{
+  if ( item )
+  {
+    QgsSettings settings;
+    const QString lastUsedDir = settings.value( QStringLiteral( "UI/lastGeoPackageDir" ), QDir::homePath() ).toString();
+
+    QString filename = QFileDialog::getSaveFileName( nullptr, tr( "New GeoPackage" ), lastUsedDir, tr( "GeoPackage" ) + " (*.gpkg *.GPKG)" );
+    if ( filename.isEmpty() )
+    {
+      return;
+    }
+
+    filename = QgsFileUtils::ensureFileNameHasExtension( filename, QStringList() << QStringLiteral( "gpkg" ) );
+
+    const QFileInfo fileInfo( filename );
+    settings.setValue( QStringLiteral( "UI/lastGeoPackageDir" ), fileInfo.absoluteDir().absolutePath() );
+
+    if ( QgsProviderMetadata *ogrMetadata = QgsProviderRegistry::instance()->providerMetadata( QStringLiteral( "ogr" ) ) )
+    {
+      QString error;
+      if ( !ogrMetadata->createDatabase( filename, error ) )
+      {
+        QMessageBox::critical( nullptr, tr( "New GeoPackage" ), error );
+        return;
+      }
+
+      // Call QFileInfo to normalize paths, see: https://github.com/qgis/QGIS/issues/36832
+      if ( QgsOgrProviderUtils::saveConnection( fileInfo.filePath(), QStringLiteral( "GPKG" ) ) )
+      {
+        item->refreshConnections();
+      }
+    }
+  }
+}
+
+void QgsGeoPackageItemGuiProvider::createDatabaseAndLayer( const QPointer<QgsGeoPackageRootItem> &item )
 {
   if ( item )
   {
     QgsNewGeoPackageLayerDialog dialog( nullptr );
     dialog.setCrs( QgsProject::instance()->defaultCrsForNewLayers() );
+
     if ( dialog.exec() == QDialog::Accepted )
     {
       // Call QFileInfo to normalize paths, see: https://github.com/qgis/QGIS/issues/36832
@@ -362,7 +414,7 @@ void QgsGeoPackageItemGuiProvider::createDatabase( const QPointer< QgsGeoPackage
 
 bool QgsGeoPackageItemGuiProvider::acceptDrop( QgsDataItem *item, QgsDataItemGuiContext )
 {
-  if ( qobject_cast< QgsGeoPackageCollectionItem * >( item ) )
+  if ( qobject_cast<QgsGeoPackageCollectionItem *>( item ) )
   {
     return true;
   }
@@ -371,7 +423,7 @@ bool QgsGeoPackageItemGuiProvider::acceptDrop( QgsDataItem *item, QgsDataItemGui
 
 bool QgsGeoPackageItemGuiProvider::handleDrop( QgsDataItem *item, QgsDataItemGuiContext context, const QMimeData *data, Qt::DropAction )
 {
-  if ( QgsGeoPackageCollectionItem *collectionItem = qobject_cast< QgsGeoPackageCollectionItem * >( item ) )
+  if ( QgsGeoPackageCollectionItem *collectionItem = qobject_cast<QgsGeoPackageCollectionItem *>( item ) )
   {
     return handleDropGeopackage( collectionItem, data, context );
   }
@@ -383,17 +435,26 @@ bool QgsGeoPackageItemGuiProvider::handleDropGeopackage( QgsGeoPackageCollection
   if ( !QgsMimeDataUtils::isUriList( data ) )
     return false;
 
+  const QgsMimeDataUtils::UriList sourceUris = QgsMimeDataUtils::decodeUriList( data );
+  if ( sourceUris.size() == 1 && sourceUris.at( 0 ).layerType == QLatin1String( "vector" ) )
+  {
+    return handleDropUri( item, sourceUris.at( 0 ), context );
+  }
+
+  std::unique_ptr<QgsAbstractDatabaseProviderConnection> databaseConnection( item->databaseConnection() );
+  if ( !databaseConnection )
+    return false;
+
   QString uri;
 
   QStringList importResults;
   bool hasError = false;
 
   // Main task
-  std::unique_ptr< QgsTaskWithSerialSubTasks > mainTask( new QgsTaskWithSerialSubTasks( tr( "GeoPackage import" ) ) );
+  auto mainTask = std::make_unique<QgsTaskWithSerialSubTasks>( tr( "GeoPackage import" ) );
   bool hasSubTasks = false;
 
-  const auto lst = QgsMimeDataUtils::decodeUriList( data );
-  for ( const QgsMimeDataUtils::Uri &dropUri : lst )
+  for ( const QgsMimeDataUtils::Uri &dropUri : sourceUris )
   {
     // Check that we are not copying over self
     if ( dropUri.uri.startsWith( item->path() ) )
@@ -456,33 +517,35 @@ bool QgsGeoPackageItemGuiProvider::handleDropGeopackage( QgsGeoPackageCollection
 
         if ( exists && !isVector )
         {
-          notify( tr( "Cannot Overwrite Layer" ),
-                  tr( "Destination layer <b>%1</b> already exists. Overwriting with raster layers is not currently supported." ).arg( dropUri.name ), context, Qgis::MessageLevel::Critical );
+          notify( tr( "Cannot Overwrite Layer" ), tr( "Destination layer <b>%1</b> already exists. Overwriting with raster layers is not currently supported." ).arg( dropUri.name ), context, Qgis::MessageLevel::Critical );
         }
-        else if ( ! exists || QMessageBox::question( nullptr, tr( "Overwrite Layer" ),
-                  tr( "Destination layer <b>%1</b> already exists. Do you want to overwrite it?" ).arg( dropUri.name ), QMessageBox::Yes |  QMessageBox::No ) == QMessageBox::Yes )
+        else if ( !exists || QMessageBox::question( nullptr, tr( "Overwrite Layer" ), tr( "Destination layer <b>%1</b> already exists. Do you want to overwrite it?" ).arg( dropUri.name ), QMessageBox::Yes | QMessageBox::No ) == QMessageBox::Yes )
         {
           if ( isVector ) // Import vectors and aspatial
           {
-            QgsVectorLayer *vectorSrcLayer = qobject_cast < QgsVectorLayer * >( srcLayer );
-            QVariantMap options;
-            options.insert( QStringLiteral( "driverName" ), QStringLiteral( "GPKG" ) );
-            options.insert( QStringLiteral( "update" ), true );
-            options.insert( QStringLiteral( "overwrite" ), true );
-            options.insert( QStringLiteral( "layerName" ), dropUri.name );
-            QgsVectorLayerExporterTask *exportTask = new QgsVectorLayerExporterTask( vectorSrcLayer, uri, QStringLiteral( "ogr" ), vectorSrcLayer->crs(), options, owner );
+            QgsVectorLayer *vectorSrcLayer = qobject_cast<QgsVectorLayer *>( srcLayer );
+
+            QVariantMap providerOptions;
+            QgsAbstractDatabaseProviderConnection::VectorLayerExporterOptions exporterOptions;
+            exporterOptions.layerName = dropUri.name;
+            exporterOptions.wkbType = vectorSrcLayer->wkbType();
+            const QString destUri = databaseConnection->createVectorLayerExporterDestinationUri( exporterOptions, providerOptions );
+
+            providerOptions.insert( QStringLiteral( "driverName" ), QStringLiteral( "GPKG" ) );
+            providerOptions.insert( QStringLiteral( "update" ), true );
+            providerOptions.insert( QStringLiteral( "overwrite" ), true );
+
+            QgsVectorLayerExporterTask *exportTask = new QgsVectorLayerExporterTask( vectorSrcLayer, destUri, QStringLiteral( "ogr" ), vectorSrcLayer->crs(), providerOptions, owner );
             mainTask->addSubTask( exportTask );
             hasSubTasks = true;
             // when export is successful:
-            connect( exportTask, &QgsVectorLayerExporterTask::exportComplete, item, [ = ]()
-            {
+            connect( exportTask, &QgsVectorLayerExporterTask::exportComplete, item, [=]() {
               notify( tr( "Import to GeoPackage database" ), tr( "Import was successful." ), context, Qgis::MessageLevel::Success );
               item->refresh();
             } );
 
             // when an error occurs:
-            connect( exportTask, &QgsVectorLayerExporterTask::errorOccurred, item, [ = ]( Qgis::VectorExportResult error, const QString & errorMessage )
-            {
+            connect( exportTask, &QgsVectorLayerExporterTask::errorOccurred, item, [=]( Qgis::VectorExportResult error, const QString &errorMessage ) {
               if ( error != Qgis::VectorExportResult::UserCanceled )
               {
                 QgsMessageOutput *output = QgsMessageOutput::createMessageOutput();
@@ -491,23 +554,20 @@ bool QgsGeoPackageItemGuiProvider::handleDropGeopackage( QgsGeoPackageCollection
                 output->showMessage();
               }
             } );
-
           }
-          else  // Import raster
+          else // Import raster
           {
-            QgsGeoPackageRasterWriterTask  *exportTask = new QgsGeoPackageRasterWriterTask( dropUri, item->path() );
+            QgsGeoPackageRasterWriterTask *exportTask = new QgsGeoPackageRasterWriterTask( dropUri, item->path() );
             mainTask->addSubTask( exportTask );
             hasSubTasks = true;
             // when export is successful:
-            connect( exportTask, &QgsGeoPackageRasterWriterTask::writeComplete, item, [ = ]()
-            {
+            connect( exportTask, &QgsGeoPackageRasterWriterTask::writeComplete, item, [=]() {
               notify( tr( "Import to GeoPackage database" ), tr( "Import was successful." ), context, Qgis::MessageLevel::Success );
               item->refresh();
             } );
 
             // when an error occurs:
-            connect( exportTask, &QgsGeoPackageRasterWriterTask::errorOccurred, item, [ = ]( QgsGeoPackageRasterWriter::WriterError error, const QString & errorMessage )
-            {
+            connect( exportTask, &QgsGeoPackageRasterWriterTask::errorOccurred, item, [=]( QgsGeoPackageRasterWriter::WriterError error, const QString &errorMessage ) {
               if ( error != QgsGeoPackageRasterWriter::WriterError::ErrUserCanceled )
               {
                 QgsMessageOutput *output = QgsMessageOutput::createMessageOutput();
@@ -520,7 +580,6 @@ bool QgsGeoPackageItemGuiProvider::handleDropGeopackage( QgsGeoPackageCollection
               QString deleteErr;
               item->deleteRasterLayer( dropUri.name, deleteErr );
             } );
-
           }
         } // do not overwrite
       }
@@ -546,4 +605,65 @@ bool QgsGeoPackageItemGuiProvider::handleDropGeopackage( QgsGeoPackageCollection
   return true;
 }
 
+bool QgsGeoPackageItemGuiProvider::handleDropUri( QgsGeoPackageCollectionItem *connectionItem, const QgsMimeDataUtils::Uri &sourceUri, QgsDataItemGuiContext context )
+{
+  QPointer< QgsGeoPackageCollectionItem > connectionItemPointer( connectionItem );
+  std::unique_ptr<QgsAbstractDatabaseProviderConnection> databaseConnection( connectionItem->databaseConnection() );
+  if ( !databaseConnection )
+    return false;
+
+  auto onSuccess = [connectionItemPointer]() {
+    if ( connectionItemPointer )
+    {
+      connectionItemPointer->refresh();
+    }
+  };
+
+  auto onFailure = [connectionItemPointer = std::move( connectionItemPointer )]( Qgis::VectorExportResult, const QString & ) {
+    if ( connectionItemPointer )
+    {
+      connectionItemPointer->refresh();
+    }
+  };
+
+  QVariantMap providerOptions;
+  providerOptions.insert( QStringLiteral( "driverName" ), QStringLiteral( "GPKG" ) );
+  providerOptions.insert( QStringLiteral( "update" ), true );
+  providerOptions.insert( QStringLiteral( "overwrite" ), true );
+
+  return QgsDataItemGuiProviderUtils::handleDropUriForConnection( std::move( databaseConnection ), sourceUri, QString(), context, tr( "GeoPackage Import" ), tr( "Import to GeoPackage database" ), providerOptions, onSuccess, onFailure, this );
+}
+
+void QgsGeoPackageItemGuiProvider::handleImportVector( QgsGeoPackageCollectionItem *connectionItem, QgsDataItemGuiContext context )
+{
+  if ( !connectionItem )
+    return;
+
+  QPointer< QgsGeoPackageCollectionItem > connectionItemPointer( connectionItem );
+  std::unique_ptr<QgsAbstractDatabaseProviderConnection> databaseConnection( connectionItem->databaseConnection() );
+  if ( !databaseConnection )
+    return;
+
+  auto onSuccess = [connectionItemPointer]() {
+    if ( connectionItemPointer )
+    {
+      connectionItemPointer->refresh();
+    }
+  };
+
+  auto onFailure = [connectionItemPointer = std::move( connectionItemPointer )]( Qgis::VectorExportResult, const QString & ) {
+    if ( connectionItemPointer )
+    {
+      connectionItemPointer->refresh();
+    }
+  };
+
+  QVariantMap providerOptions;
+  providerOptions.insert( QStringLiteral( "driverName" ), QStringLiteral( "GPKG" ) );
+  providerOptions.insert( QStringLiteral( "update" ), true );
+  providerOptions.insert( QStringLiteral( "overwrite" ), true );
+
+  return QgsDataItemGuiProviderUtils::handleImportVectorLayerForConnection( std::move( databaseConnection ), QString(), context, tr( "GeoPackage Import" ), tr( "Import to GeoPackage database" ), providerOptions, onSuccess, onFailure, this );
+}
+
 ///@endcond
