@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsfontbutton.h"
+#include "moc_qgsfontbutton.cpp"
 #include "qgstextformatwidget.h"
 #include "qgssymbollayerutils.h"
 #include "qgscolorscheme.h"
@@ -58,7 +59,7 @@ QgsFontButton::QgsFontButton( QWidget *parent, const QString &dialogTitle )
   mSizeHint = QSize( std::max( minWidth, size.width() ), std::max( size.height(), fontHeight ) );
 
   mScreenHelper = new QgsScreenHelper( this );
-  connect( mScreenHelper, &QgsScreenHelper::screenDpiChanged, this, [ = ] { updatePreview(); } );
+  connect( mScreenHelper, &QgsScreenHelper::screenDpiChanged, this, [=] { updatePreview(); } );
 }
 
 QSize QgsFontButton::minimumSizeHint() const
@@ -79,7 +80,7 @@ void QgsFontButton::showSettingsDialog()
     {
       QgsExpressionContext context;
       if ( mExpressionContextGenerator )
-        context  = mExpressionContextGenerator->createExpressionContext();
+        context = mExpressionContextGenerator->createExpressionContext();
       else
       {
         context.appendScopes( QgsExpressionContextUtils::globalProjectLayerScopes( mLayer.data() ) );
@@ -97,7 +98,7 @@ void QgsFontButton::showSettingsDialog()
         mActivePanel->setPanelTitle( mDialogTitle );
         mActivePanel->setContext( symbolContext );
 
-        connect( mActivePanel, &QgsTextFormatPanelWidget::widgetChanged, this, [ this ] { setTextFormat( mActivePanel->format() ); } );
+        connect( mActivePanel, &QgsTextFormatPanelWidget::widgetChanged, this, [this] { setTextFormat( mActivePanel->format() ); } );
         panel->openPanel( mActivePanel );
         return;
       }
@@ -221,7 +222,7 @@ bool QgsFontButton::event( QEvent *e )
 {
   if ( e->type() == QEvent::ToolTip )
   {
-    QHelpEvent *helpEvent = static_cast< QHelpEvent *>( e );
+    QHelpEvent *helpEvent = static_cast<QHelpEvent *>( e );
     QString toolTip;
     double fontSize = 0.0;
     switch ( mMode )
@@ -483,7 +484,7 @@ QPixmap QgsFontButton::createDragIcon( QSize size, const QgsTextFormat *tempForm
       context.setMapToPixel( newCoordXForm );
 
       context.setScaleFactor( mScreenHelper->screenDpi() / 25.4 );
-      context.setUseAdvancedEffects( true );
+      context.setRasterizedRenderingPolicy( Qgis::RasterizedRenderingPolicy::PreferVector );
       context.setPainter( &p );
 
       // slightly inset text to account for buffer/background
@@ -491,16 +492,14 @@ QPixmap QgsFontButton::createDragIcon( QSize size, const QgsTextFormat *tempForm
       double xtrans = 0;
       if ( tempFormat->buffer().enabled() )
         xtrans = tempFormat->buffer().sizeUnit() == Qgis::RenderUnit::Percentage
-                 ? fontSize * tempFormat->buffer().size() / 100
-                 : context.convertToPainterUnits( tempFormat->buffer().size(), tempFormat->buffer().sizeUnit(), tempFormat->buffer().sizeMapUnitScale() );
+                   ? fontSize * tempFormat->buffer().size() / 100
+                   : context.convertToPainterUnits( tempFormat->buffer().size(), tempFormat->buffer().sizeUnit(), tempFormat->buffer().sizeMapUnitScale() );
       if ( tempFormat->background().enabled() && tempFormat->background().sizeType() != QgsTextBackgroundSettings::SizeFixed )
         xtrans = std::max( xtrans, context.convertToPainterUnits( tempFormat->background().size().width(), tempFormat->background().sizeUnit(), tempFormat->background().sizeMapUnitScale() ) );
 
       double ytrans = 0.0;
       if ( tempFormat->buffer().enabled() )
-        ytrans = std::max( ytrans, tempFormat->buffer().sizeUnit() == Qgis::RenderUnit::Percentage
-                           ? fontSize * tempFormat->buffer().size() / 100
-                           : context.convertToPainterUnits( tempFormat->buffer().size(), tempFormat->buffer().sizeUnit(), tempFormat->buffer().sizeMapUnitScale() ) );
+        ytrans = std::max( ytrans, tempFormat->buffer().sizeUnit() == Qgis::RenderUnit::Percentage ? fontSize * tempFormat->buffer().size() / 100 : context.convertToPainterUnits( tempFormat->buffer().size(), tempFormat->buffer().sizeUnit(), tempFormat->buffer().sizeMapUnitScale() ) );
       if ( tempFormat->background().enabled() )
         ytrans = std::max( ytrans, context.convertToPainterUnits( tempFormat->background().size().height(), tempFormat->background().sizeUnit(), tempFormat->background().sizeMapUnitScale() ) );
 
@@ -513,8 +512,7 @@ QPixmap QgsFontButton::createDragIcon( QSize size, const QgsTextFormat *tempForm
       if ( textRect.width() > 2000 )
         textRect.setWidth( 2000 );
 
-      QgsTextRenderer::drawText( textRect, 0, Qgis::TextHorizontalAlignment::Center, QStringList() << tr( "Aa" ),
-                                 context, *tempFormat );
+      QgsTextRenderer::drawText( textRect, 0, Qgis::TextHorizontalAlignment::Center, QStringList() << tr( "Aa" ), context, *tempFormat );
       break;
     }
     case ModeQFont:
@@ -579,9 +577,7 @@ void QgsFontButton::prepareMenu()
   sizeSpin->setMaximum( 1e+9 );
   sizeSpin->setShowClearButton( false );
   sizeSpin->setValue( mMode == ModeTextRenderer ? mFormat.size() : mFont.pointSizeF() );
-  connect( sizeSpin, static_cast < void ( QgsDoubleSpinBox::* )( double ) > ( &QgsDoubleSpinBox::valueChanged ),
-           this, [ = ]( double value )
-  {
+  connect( sizeSpin, static_cast<void ( QgsDoubleSpinBox::* )( double )>( &QgsDoubleSpinBox::valueChanged ), this, [=]( double value ) {
     switch ( mMode )
     {
       case ModeTextRenderer:
@@ -622,8 +618,7 @@ void QgsFontButton::prepareMenu()
       fontAction->setCheckable( true );
       fontAction->setChecked( true );
     }
-    auto setFont = [this, family]
-    {
+    auto setFont = [this, family] {
       switch ( mMode )
       {
         case ModeTextRenderer:
@@ -698,8 +693,7 @@ void QgsFontButton::prepareMenu()
     alphaRamp->setColor( alphaColor );
     QgsColorWidgetAction *alphaAction = new QgsColorWidgetAction( alphaRamp, mMenu, mMenu );
     alphaAction->setDismissOnColorSelection( false );
-    connect( alphaAction, &QgsColorWidgetAction::colorChanged, this, [ = ]( const QColor & color )
-    {
+    connect( alphaAction, &QgsColorWidgetAction::colorChanged, this, [=]( const QColor &color ) {
       const double opacity = color.alphaF();
       mFormat.setOpacity( opacity );
       updatePreview();
@@ -707,13 +701,12 @@ void QgsFontButton::prepareMenu()
         mNullFormatAction->setChecked( false );
       emit changed();
     } );
-    connect( colorAction, &QgsColorWidgetAction::colorChanged, alphaRamp, [alphaRamp]( const QColor & color ) { alphaRamp->setColor( color, false ); }
-           );
+    connect( colorAction, &QgsColorWidgetAction::colorChanged, alphaRamp, [alphaRamp]( const QColor &color ) { alphaRamp->setColor( color, false ); } );
     mMenu->addAction( alphaAction );
 
     //get schemes with ShowInColorButtonMenu flag set
-    QList< QgsColorScheme * > schemeList = QgsApplication::colorSchemeRegistry()->schemes( QgsColorScheme::ShowInColorButtonMenu );
-    QList< QgsColorScheme * >::iterator it = schemeList.begin();
+    QList<QgsColorScheme *> schemeList = QgsApplication::colorSchemeRegistry()->schemes( QgsColorScheme::ShowInColorButtonMenu );
+    QList<QgsColorScheme *>::iterator it = schemeList.begin();
     for ( ; it != schemeList.end(); ++it )
     {
       QgsColorSwatchGridAction *colorAction = new QgsColorSwatchGridAction( *it, mMenu, QStringLiteral( "labeling" ), this );
@@ -792,6 +785,9 @@ void QgsFontButton::setMode( Mode mode )
 
 bool QgsFontButton::formatFromMimeData( const QMimeData *mimeData, QgsTextFormat &resultFormat ) const
 {
+  if ( !mimeData )
+    return false;
+
   bool ok = false;
   resultFormat = QgsTextFormat::fromMimeData( mimeData, &ok );
   return ok;
@@ -799,6 +795,9 @@ bool QgsFontButton::formatFromMimeData( const QMimeData *mimeData, QgsTextFormat
 
 bool QgsFontButton::fontFromMimeData( const QMimeData *mimeData, QFont &resultFont ) const
 {
+  if ( !mimeData )
+    return false;
+
   bool ok = false;
   resultFont = QgsFontUtils::fromMimeData( mimeData, &ok );
   return ok;
@@ -866,12 +865,11 @@ void QgsFontButton::updatePreview( const QColor &color, QgsTextFormat *format, Q
       //calculate size of push button part of widget (ie, without the menu dropdown button part)
       QStyleOptionToolButton opt;
       initStyleOption( &opt );
-      const QRect buttonSize = QApplication::style()->subControlRect( QStyle::CC_ToolButton, &opt, QStyle::SC_ToolButton,
-                               this );
+      const QRect buttonSize = QApplication::style()->subControlRect( QStyle::CC_ToolButton, &opt, QStyle::SC_ToolButton, this );
       //make sure height of icon looks good under different platforms
 #ifdef Q_OS_WIN
       mIconSize = QSize( buttonSize.width() - 10, height() - 6 );
-#elif defined(Q_OS_MAC)
+#elif defined( Q_OS_MAC )
       mIconSize = QSize( buttonSize.width() - 10, height() - 2 );
 #else
       mIconSize = QSize( buttonSize.width() - 10, height() - 12 );
@@ -914,7 +912,7 @@ void QgsFontButton::updatePreview( const QColor &color, QgsTextFormat *format, Q
 
       context.setScaleFactor( mScreenHelper->screenDpi() / 25.4 );
       context.setDevicePixelRatio( devicePixelRatioF() );
-      context.setUseAdvancedEffects( true );
+      context.setRasterizedRenderingPolicy( Qgis::RasterizedRenderingPolicy::PreferVector );
       context.setFlag( Qgis::RenderContextFlag::Antialiasing, true );
       context.setPainter( &p );
 
@@ -923,16 +921,14 @@ void QgsFontButton::updatePreview( const QColor &color, QgsTextFormat *format, Q
       double xtrans = 0;
       if ( tempFormat.buffer().enabled() )
         xtrans = tempFormat.buffer().sizeUnit() == Qgis::RenderUnit::Percentage
-                 ? fontSize * tempFormat.buffer().size() / 100
-                 : context.convertToPainterUnits( tempFormat.buffer().size(), tempFormat.buffer().sizeUnit(), tempFormat.buffer().sizeMapUnitScale() );
+                   ? fontSize * tempFormat.buffer().size() / 100
+                   : context.convertToPainterUnits( tempFormat.buffer().size(), tempFormat.buffer().sizeUnit(), tempFormat.buffer().sizeMapUnitScale() );
       if ( tempFormat.background().enabled() && tempFormat.background().sizeType() != QgsTextBackgroundSettings::SizeFixed )
         xtrans = std::max( xtrans, context.convertToPainterUnits( tempFormat.background().size().width(), tempFormat.background().sizeUnit(), tempFormat.background().sizeMapUnitScale() ) );
 
       double ytrans = 0.0;
       if ( tempFormat.buffer().enabled() )
-        ytrans = std::max( ytrans, tempFormat.buffer().sizeUnit() == Qgis::RenderUnit::Percentage
-                           ? fontSize * tempFormat.buffer().size() / 100
-                           : context.convertToPainterUnits( tempFormat.buffer().size(), tempFormat.buffer().sizeUnit(), tempFormat.buffer().sizeMapUnitScale() ) );
+        ytrans = std::max( ytrans, tempFormat.buffer().sizeUnit() == Qgis::RenderUnit::Percentage ? fontSize * tempFormat.buffer().size() / 100 : context.convertToPainterUnits( tempFormat.buffer().size(), tempFormat.buffer().sizeUnit(), tempFormat.buffer().sizeMapUnitScale() ) );
       if ( tempFormat.background().enabled() )
         ytrans = std::max( ytrans, context.convertToPainterUnits( tempFormat.background().size().height(), tempFormat.background().sizeUnit(), tempFormat.background().sizeMapUnitScale() ) );
 
@@ -945,8 +941,7 @@ void QgsFontButton::updatePreview( const QColor &color, QgsTextFormat *format, Q
       if ( textRect.width() > 2000 )
         textRect.setWidth( 2000 );
 
-      QgsTextRenderer::drawText( textRect, 0, Qgis::TextHorizontalAlignment::Left, QStringList() << text(),
-                                 context, tempFormat );
+      QgsTextRenderer::drawText( textRect, 0, Qgis::TextHorizontalAlignment::Left, QStringList() << text(), context, tempFormat );
       break;
     }
     case ModeQFont:
@@ -959,7 +954,6 @@ void QgsFontButton::updatePreview( const QColor &color, QgsTextFormat *format, Q
       p.drawText( textRect, Qt::AlignVCenter, text() );
       break;
     }
-
   }
   p.end();
   setIconSize( currentIconSize );
