@@ -32,13 +32,6 @@
 class QgsWFSDataSourceURI
 {
   public:
-    //! Http method for DCP URIs
-    enum Method
-    {
-      Get,
-      Post
-    };
-
     explicit QgsWFSDataSourceURI( const QString &uri );
 
     //! Copy constructor
@@ -54,7 +47,7 @@ class QgsWFSDataSourceURI
     QUrl baseURL( bool bIncludeServiceWFS = true ) const;
 
     //! Returns request URL (with SERVICE=WFS parameter)
-    QUrl requestUrl( const QString &request, const Method &method = Method::Get ) const;
+    QUrl requestUrl( const QString &request, Qgis::HttpMethod method = Qgis::HttpMethod::Get ) const;
 
     //! Gets WFS version. Can be auto, 1.0.0, 1.1.0 or 2.0.0.
     QString version() const;
@@ -118,6 +111,9 @@ class QgsWFSDataSourceURI
     //! Sets GetFeature output format
     void setOutputFormat( const QString &outputFormat );
 
+    //! Returns the preferred HTTP method for requests
+    Qgis::HttpMethod httpMethod() const;
+
     //! Returns whether GetFeature request should include the request bounding box. Defaults to false
     bool isRestrictedToRequestBBOX() const;
 
@@ -139,6 +135,17 @@ class QgsWFSDataSourceURI
     //! Returns authorization parameters
     const QgsAuthorizationSettings &auth() const { return mAuth; }
 
+    //! How to analyze DescribeFeatureType response
+    enum class FeatureMode
+    {
+      Default,         //! If the server supports transaction, same as SIMPLE_FEATURE. Otherwise COMPLEX_FEATURE
+      SimpleFeatures,  //! Analyze DescribeFeatureType response with QGIS built-in Simple Feature analyzer
+      ComplexFeatures, //! Analyze DescribeFeatureType response with OGR GMLAS Complex Feature analyzer
+    };
+
+    //! Returns how to analyze DescribeFeatureType response.
+    FeatureMode featureMode() const;
+
     //! Builds a derived uri from a base uri
     static QString build( const QString &uri, const QString &typeName, const QString &crsString = QString(), const QString &sql = QString(), const QString &filter = QString(), bool restrictToCurrentViewExtent = false );
 
