@@ -31,6 +31,7 @@
 #include "qgslogger.h"
 #include "qgsmapserviceexception.h"
 #include "qgsnetworkaccessmanager.h"
+#include "qgsnetworkdiskcache.h"
 #include "qgsserverlogger.h"
 #include "qgsserverrequest.h"
 #include "qgsfilterresponsedecorator.h"
@@ -69,7 +70,7 @@ Q_GLOBAL_STATIC( QgsServerSettings, sSettings );
 QgsServer::QgsServer()
 {
   // QgsApplication must exist
-  if ( qobject_cast<QgsApplication *>( qApp ) == nullptr )
+  if ( !qobject_cast<QgsApplication *>( qApp ) )
   {
     qFatal( "A QgsApplication must exist before a QgsServer instance can be created." );
     abort();
@@ -88,9 +89,9 @@ void QgsServer::setupNetworkAccessManager()
   const QSettings settings;
   QgsNetworkAccessManager *nam = QgsNetworkAccessManager::instance();
   QNetworkDiskCache *cache = new QNetworkDiskCache( nullptr );
-  const qint64 cacheSize = sSettings()->cacheSize();
   const QString cacheDirectory = sSettings()->cacheDirectory();
   cache->setCacheDirectory( cacheDirectory );
+  qint64 cacheSize = sSettings()->cacheSize();
   cache->setMaximumCacheSize( cacheSize );
   QgsMessageLog::logMessage( QStringLiteral( "cacheDirectory: %1" ).arg( cache->cacheDirectory() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   QgsMessageLog::logMessage( QStringLiteral( "maximumCacheSize: %1" ).arg( cache->maximumCacheSize() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
@@ -116,14 +117,14 @@ QFileInfo QgsServer::defaultProjectFile()
   return projectFiles.at( 0 );
 }
 
-void QgsServer::printRequestParameters( const QMap< QString, QString> &parameterMap, Qgis::MessageLevel logLevel )
+void QgsServer::printRequestParameters( const QMap<QString, QString> &parameterMap, Qgis::MessageLevel logLevel )
 {
   if ( logLevel > Qgis::MessageLevel::Info )
   {
     return;
   }
 
-  QMap< QString, QString>::const_iterator pIt = parameterMap.constBegin();
+  QMap<QString, QString>::const_iterator pIt = parameterMap.constBegin();
   for ( ; pIt != parameterMap.constEnd(); ++pIt )
   {
     QgsMessageLog::logMessage( pIt.key() + ":" + pIt.value(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
@@ -149,7 +150,7 @@ QString QgsServer::configPath( const QString &defaultConfigPath, const QString &
         cfPath = getenv( "QGIS_PROJECT_FILE" );
         QgsMessageLog::logMessage( QStringLiteral( "Using configuration file path from environment: %1" ).arg( cfPath ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
       }
-      else  if ( ! defaultConfigPath.isEmpty() )
+      else if ( !defaultConfigPath.isEmpty() )
       {
         QgsMessageLog::logMessage( QStringLiteral( "Using default configuration file path: %1" ).arg( defaultConfigPath ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
       }
@@ -166,7 +167,7 @@ QString QgsServer::configPath( const QString &defaultConfigPath, const QString &
 void QgsServer::initLocale()
 {
   // System locale override
-  if ( ! sSettings()->overrideSystemLocale().isEmpty() )
+  if ( !sSettings()->overrideSystemLocale().isEmpty() )
   {
     QLocale::setDefault( QLocale( sSettings()->overrideSystemLocale() ) );
   }
@@ -199,7 +200,7 @@ bool QgsServer::init()
   //       while     QGIS_OPTIONS_PATH gives       /tmp/qt_temp-rUpsId/QGIS/QGIS3.ini
   QgsApplication::init( qgetenv( "QGIS_OPTIONS_PATH" ) );
 
-#if defined(SERVER_SKIP_ECW)
+#if defined( SERVER_SKIP_ECW )
   QgsMessageLog::logMessage( "Skipping GDAL ECW drivers in server.", "Server", Qgis::MessageLevel::Info );
   QgsApplication::skipGdalDriver( "ECW" );
   QgsApplication::skipGdalDriver( "JP2ECW" );
@@ -212,7 +213,7 @@ bool QgsServer::init()
   // init and configure logger
   QgsServerLogger::instance();
   QgsServerLogger::instance()->setLogLevel( sSettings()->logLevel() );
-  if ( ! sSettings()->logFile().isEmpty() )
+  if ( !sSettings()->logFile().isEmpty() )
   {
     QgsServerLogger::instance()->setLogFile( sSettings()->logFile() );
   }
@@ -222,22 +223,12 @@ bool QgsServer::init()
   }
 
   // Logging handlers for CRS grid issues
-  QgsCoordinateTransform::setCustomMissingRequiredGridHandler( [ = ]( const QgsCoordinateReferenceSystem & sourceCrs,
-      const QgsCoordinateReferenceSystem & destinationCrs,
-      const QgsDatumTransform::GridDetails & grid )
-  {
-    QgsServerLogger::instance()->logMessage( QStringLiteral( "Cannot use project transform between %1 and %2 - missing grid %3" )
-        .arg( sourceCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ),
-              destinationCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ),
-              grid.shortName ),
-        QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
+  QgsCoordinateTransform::setCustomMissingRequiredGridHandler( [=]( const QgsCoordinateReferenceSystem &sourceCrs, const QgsCoordinateReferenceSystem &destinationCrs, const QgsDatumTransform::GridDetails &grid ) {
+    QgsServerLogger::instance()->logMessage( QStringLiteral( "Cannot use project transform between %1 and %2 - missing grid %3" ).arg( sourceCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ), destinationCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ), grid.shortName ), QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
   } );
 
 
-  QgsCoordinateTransform::setCustomMissingGridUsedByContextHandler( [ = ]( const QgsCoordinateReferenceSystem & sourceCrs,
-      const QgsCoordinateReferenceSystem & destinationCrs,
-      const QgsDatumTransform::TransformDetails & details )
-  {
+  QgsCoordinateTransform::setCustomMissingGridUsedByContextHandler( [=]( const QgsCoordinateReferenceSystem &sourceCrs, const QgsCoordinateReferenceSystem &destinationCrs, const QgsDatumTransform::TransformDetails &details ) {
     QString gridMessage;
     for ( const QgsDatumTransform::GridDetails &grid : details.grids )
     {
@@ -246,21 +237,11 @@ bool QgsServer::init()
         gridMessage.append( QStringLiteral( "This transformation requires the grid file '%1', which is not available for use on the system.\n" ).arg( grid.shortName ) );
       }
     }
-    QgsServerLogger::instance()->logMessage( QStringLiteral( "Cannot use project transform between %1 and %2 - %3.\n%4" )
-        .arg( sourceCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ),
-              destinationCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ),
-              details.name,
-              gridMessage ),
-        QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
+    QgsServerLogger::instance()->logMessage( QStringLiteral( "Cannot use project transform between %1 and %2 - %3.\n%4" ).arg( sourceCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ), destinationCrs.userFriendlyIdentifier( Qgis::CrsIdentifierType::ShortString ), details.name, gridMessage ), QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
   } );
 
 
-  QgsCoordinateTransform::setCustomMissingPreferredGridHandler( [ = ]( const QgsCoordinateReferenceSystem & sourceCrs,
-      const QgsCoordinateReferenceSystem & destinationCrs,
-      const QgsDatumTransform::TransformDetails & preferredOperation,
-      const QgsDatumTransform::TransformDetails & availableOperation )
-  {
-
+  QgsCoordinateTransform::setCustomMissingPreferredGridHandler( [=]( const QgsCoordinateReferenceSystem &sourceCrs, const QgsCoordinateReferenceSystem &destinationCrs, const QgsDatumTransform::TransformDetails &preferredOperation, const QgsDatumTransform::TransformDetails &availableOperation ) {
     QString gridMessage;
     for ( const QgsDatumTransform::GridDetails &grid : preferredOperation.grids )
     {
@@ -283,25 +264,21 @@ bool QgsServer::init()
 
     QString accuracyMessage;
     if ( availableOperation.accuracy >= 0 && preferredOperation.accuracy >= 0 )
-      accuracyMessage = QStringLiteral( "Current transform '%1' has an accuracy of %2 meters, while the preferred transformation '%3' has accuracy %4 meters.\n" ).arg( availableOperation.name )
-                        .arg( availableOperation.accuracy ).arg( preferredOperation.name ).arg( preferredOperation.accuracy );
+      accuracyMessage = QStringLiteral( "Current transform '%1' has an accuracy of %2 meters, while the preferred transformation '%3' has accuracy %4 meters.\n" ).arg( availableOperation.name ).arg( availableOperation.accuracy ).arg( preferredOperation.name ).arg( preferredOperation.accuracy );
     else if ( preferredOperation.accuracy >= 0 )
       accuracyMessage = QStringLiteral( "Current transform '%1' has an unknown accuracy, while the preferred transformation '%2' has accuracy %3 meters.\n" )
-                        .arg( availableOperation.name, preferredOperation.name )
-                        .arg( preferredOperation.accuracy );
+                          .arg( availableOperation.name, preferredOperation.name )
+                          .arg( preferredOperation.accuracy );
 
-    const QString longMessage = QStringLiteral( "The preferred transform between '%1' and '%2' is not available for use on the system.\n" ).arg( sourceCrs.userFriendlyIdentifier(),
-                                destinationCrs.userFriendlyIdentifier() )
+    const QString longMessage = QStringLiteral( "The preferred transform between '%1' and '%2' is not available for use on the system.\n" ).arg( sourceCrs.userFriendlyIdentifier(), destinationCrs.userFriendlyIdentifier() )
                                 + gridMessage + accuracyMessage;
 
     QgsServerLogger::instance()->logMessage( longMessage, QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
-
   } );
 
-  QgsCoordinateTransform::setCustomCoordinateOperationCreationErrorHandler( [ = ]( const QgsCoordinateReferenceSystem & sourceCrs, const QgsCoordinateReferenceSystem & destinationCrs, const QString & error )
-  {
+  QgsCoordinateTransform::setCustomCoordinateOperationCreationErrorHandler( [=]( const QgsCoordinateReferenceSystem &sourceCrs, const QgsCoordinateReferenceSystem &destinationCrs, const QString &error ) {
     const QString longMessage = QStringLiteral( "No transform is available between %1 and %2: %3" )
-                                .arg( sourceCrs.userFriendlyIdentifier(), destinationCrs.userFriendlyIdentifier(), error );
+                                  .arg( sourceCrs.userFriendlyIdentifier(), destinationCrs.userFriendlyIdentifier(), error );
     QgsServerLogger::instance()->logMessage( longMessage, QStringLiteral( "QGIS Server" ), Qgis::MessageLevel::Warning );
   } );
 
@@ -322,16 +299,17 @@ bool QgsServer::init()
   QgsMessageLog::logMessage( "Plugin  PATH: " + QgsApplication::pluginPath(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   QgsMessageLog::logMessage( "PkgData PATH: " + QgsApplication::pkgDataPath(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   QgsMessageLog::logMessage( "User DB PATH: " + QgsApplication::qgisUserDatabaseFilePath(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
-  QgsMessageLog::logMessage( "Auth DB PATH: " + QgsApplication::qgisAuthDatabaseFilePath(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+  QgsMessageLog::logMessage( "Auth DB URI: " + QgsApplication::qgisAuthDatabaseUri(), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   QgsMessageLog::logMessage( "SVG PATHS: " + QgsApplication::svgPaths().join( QDir::listSeparator() ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
 
   QgsApplication::createDatabase(); //init qgis.db (e.g. necessary for user crs)
 
   // Sets up the authentication system
   //   creates or uses qgis-auth.db in ~/.qgis3/ or directory defined by QGIS_AUTH_DB_DIR_PATH env variable
+  //   or QGIS_AUTH_DB_URI env variable.
   //   set the master password as first line of file defined by QGIS_AUTH_PASSWORD_FILE env variable
   //   (QGIS_AUTH_PASSWORD_FILE variable removed from environment after accessing)
-  QgsApplication::authManager()->setup( QgsApplication::pluginPath(), QgsApplication::qgisAuthDatabaseFilePath() );
+  QgsApplication::authManager()->setup( QgsApplication::pluginPath(), QgsApplication::qgisAuthDatabaseUri() );
 
   QString defaultConfigFilePath;
   const QFileInfo projectFileInfo = defaultProjectFile(); //try to find a .qgs/.qgz file in the server directory
@@ -363,7 +341,7 @@ bool QgsServer::init()
   // Load service module
   const QString modulePath = QgsApplication::libexecPath() + "server";
   // qDebug() << QStringLiteral( "Initializing server modules from: %1" ).arg( modulePath );
-  sServiceRegistry->init( modulePath,  sServerInterface );
+  sServiceRegistry->init( modulePath, sServerInterface );
 
   // Initialize config cache
   QgsConfigCache::initialize( sSettings );
@@ -376,7 +354,6 @@ bool QgsServer::init()
 }
 
 
-
 void QgsServer::putenv( const QString &var, const QString &val )
 {
   if ( val.isEmpty() )
@@ -394,7 +371,6 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
 {
   const Qgis::MessageLevel logLevel = QgsServerLogger::instance()->logLevel();
   {
-
     const QgsScopedRuntimeProfile profiler { QStringLiteral( "handleRequest" ), QStringLiteral( "server" ) };
 
     qApp->processEvents();
@@ -418,15 +394,19 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
     //Request handler
     QgsRequestHandler requestHandler( request, response );
 
-    try
+    if ( !response.feedback()
+         || !response.feedback()->isCanceled() ) // to avoid to much log when request is canceled
     {
-      // TODO: split parse input into plain parse and processing from specific services
-      requestHandler.parseInput();
-    }
-    catch ( QgsMapServiceException &e )
-    {
-      QgsMessageLog::logMessage( "Parse input exception: " + e.message(), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
-      requestHandler.setServiceException( e );
+      try
+      {
+        // TODO: split parse input into plain parse and processing from specific services
+        requestHandler.parseInput();
+      }
+      catch ( QgsMapServiceException &e )
+      {
+        QgsMessageLog::logMessage( "Parse input exception: " + e.message(), QStringLiteral( "Server" ), Qgis::MessageLevel::Critical );
+        requestHandler.setServiceException( e );
+      }
     }
 
     // Set the request handler into the interface for plugins to manipulate it
@@ -436,7 +416,7 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
     // before calling plugin methods
     // Note that plugins may still change that value using
     // setConfigFilePath() interface method
-    if ( ! project )
+    if ( !project )
     {
       const QString configFilePath = configPath( *sConfigFilePath, request.serverParameters().map() );
       sServerInterface->setConfigFilePath( configFilePath );
@@ -460,7 +440,7 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
     }
 
     // Plugins may have set exceptions
-    if ( !requestHandler.exceptionRaised() )
+    if ( !requestHandler.exceptionRaised() && ( !response.feedback() || !response.feedback()->isCanceled() ) )
     {
       try
       {
@@ -473,7 +453,7 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
           const QString configFilePath = configPath( *sConfigFilePath, params.map() );
 
           // load the project if needed and not empty
-          if ( ! configFilePath.isEmpty() )
+          if ( !configFilePath.isEmpty() )
           {
             // Note that  QgsConfigCache::project( ... ) call QgsProject::setInstance(...)
             project = mConfigCache->project( configFilePath, sServerInterface->serverSettings() );
@@ -502,37 +482,58 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
 
         // Dispatcher: if SERVICE is set, we assume a OWS service, if not, let's try an API
         // TODO: QGIS 4 fix the OWS services and treat them as APIs
-        QgsServerApi *api = nullptr;
-
-        if ( params.service().isEmpty() && ( api = sServiceRegistry->apiForRequest( request ) ) )
+        if ( !response.feedback() || !response.feedback()->isCanceled() )
         {
-          const QgsServerApiContext context { api->rootPath(), &request, &responseDecorator, project, sServerInterface };
-          api->executeRequest( context );
-        }
-        else
-        {
-          // Project is mandatory for OWS at this point
-          if ( ! project )
+          if ( params.service().isEmpty() )
           {
-            throw QgsServerException( QStringLiteral( "Project file error. For OWS services: please provide a SERVICE and a MAP parameter pointing to a valid QGIS project file" ) );
-          }
-
-          if ( ! params.fileName().isEmpty() )
-          {
-            const QString value = QString( "attachment; filename=\"%1\"" ).arg( params.fileName() );
-            requestHandler.setResponseHeader( QStringLiteral( "Content-Disposition" ), value );
-          }
-
-          // Lookup for service
-          QgsService *service = sServiceRegistry->getService( params.service(), params.version() );
-          if ( service )
-          {
-            service->executeRequest( request, responseDecorator, project );
+            QgsServerApi *api = sServiceRegistry->apiForRequest( request );
+            if ( api )
+            {
+              const QgsServerApiContext context { api->rootPath(), &request, &responseDecorator, project, sServerInterface };
+              api->executeRequest( context );
+            }
+            else
+            {
+              throw QgsOgcServiceException(
+                QStringLiteral( "Service configuration error" ),
+                QStringLiteral( "Service unknown or unsupported. Current supported services "
+                                "(case-sensitive): WMS WFS WCS WMTS SampleService, or use a WFS3 "
+                                "(OGC API Features) endpoint" )
+              );
+            }
           }
           else
           {
-            throw QgsOgcServiceException( QStringLiteral( "Service configuration error" ),
-                                          QStringLiteral( "Service unknown or unsupported. Current supported services (case-sensitive): WMS WFS WCS WMTS SampleService, or use a WFS3 (OGC API Features) endpoint" ) );
+            // Project is mandatory for OWS at this point
+            if ( !project )
+            {
+              throw QgsServerException(
+                QStringLiteral( "Project file error. For OWS services: please provide a SERVICE "
+                                "and a MAP parameter pointing to a valid QGIS project file" )
+              );
+            }
+
+            if ( !params.fileName().isEmpty() )
+            {
+              const QString value = QString( "attachment; filename=\"%1\"" ).arg( params.fileName() );
+              requestHandler.setResponseHeader( QStringLiteral( "Content-Disposition" ), value );
+            }
+
+            // Lookup for service
+            QgsService *service = sServiceRegistry->getService( params.service(), params.version() );
+            if ( service )
+            {
+              service->executeRequest( request, responseDecorator, project );
+            }
+            else
+            {
+              throw QgsOgcServiceException(
+                QStringLiteral( "Service configuration error" ),
+                QStringLiteral( "Service unknown or unsupported. Current supported services "
+                                "(case-sensitive): WMS WFS WCS WMTS SampleService, or use a WFS3 "
+                                "(OGC API Features) endpoint" )
+              );
+            }
           }
         }
       }
@@ -573,24 +574,18 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
     QgsMessageLog::logMessage( "Request finished in " + QString::number( QgsApplication::profiler()->profileTime( QStringLiteral( "handleRequest" ), QStringLiteral( "server" ) ) * 1000.0 ) + " ms", QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
     if ( sSettings->logProfile() )
     {
-      std::function <void( const QModelIndex &, int )> profileFormatter;
-      profileFormatter = [ &profileFormatter ]( const QModelIndex & idx, int level )
-      {
-        QgsMessageLog::logMessage( QStringLiteral( "Profile: %1%2, %3 : %4 ms" )
-                                   .arg( level > 0 ? QString().fill( '-', level ) + ' ' : QString() )
-                                   .arg( QgsApplication::profiler()->data( idx, static_cast< int >( QgsRuntimeProfilerNode::CustomRole::Group ) ).toString() )
-                                   .arg( QgsApplication::profiler()->data( idx, static_cast< int >( QgsRuntimeProfilerNode::CustomRole::Name ) ).toString() )
-                                   .arg( QString::number( QgsApplication::profiler()->data( idx, static_cast< int >( QgsRuntimeProfilerNode::CustomRole::Elapsed ) ).toDouble() * 1000.0 ) ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
+      std::function<void( const QModelIndex &, int )> profileFormatter;
+      profileFormatter = [&profileFormatter]( const QModelIndex &idx, int level ) {
+        QgsMessageLog::logMessage( QStringLiteral( "Profile: %1%2, %3 : %4 ms" ).arg( level > 0 ? QString().fill( '-', level ) + ' ' : QString() ).arg( QgsApplication::profiler()->data( idx, static_cast<int>( QgsRuntimeProfilerNode::CustomRole::Group ) ).toString() ).arg( QgsApplication::profiler()->data( idx, static_cast<int>( QgsRuntimeProfilerNode::CustomRole::Name ) ).toString() ).arg( QString::number( QgsApplication::profiler()->data( idx, static_cast<int>( QgsRuntimeProfilerNode::CustomRole::Elapsed ) ).toDouble() * 1000.0 ) ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
 
         for ( int subRow = 0; subRow < QgsApplication::profiler()->rowCount( idx ); subRow++ )
         {
           const auto subIdx { QgsApplication::profiler()->index( subRow, 0, idx ) };
           profileFormatter( subIdx, level + 1 );
         }
-
       };
 
-      for ( int row = 0; row < QgsApplication::profiler()->rowCount( ); row++ )
+      for ( int row = 0; row < QgsApplication::profiler()->rowCount(); row++ )
       {
         const auto idx { QgsApplication::profiler()->index( row, 0 ) };
         profileFormatter( idx, 0 );
@@ -604,8 +599,6 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
   QgsApplication::profiler()->clear( QStringLiteral( "projectload" ) );
   QgsApplication::profiler()->clear( QStringLiteral( "rendering" ) );
   QgsApplication::profiler()->clear( QStringLiteral( "server" ) );
-
-
 }
 
 
@@ -613,7 +606,7 @@ void QgsServer::handleRequest( QgsServerRequest &request, QgsServerResponse &res
 void QgsServer::initPython()
 {
   // Init plugins
-  if ( ! QgsServerPlugins::initPlugins( sServerInterface ) )
+  if ( !QgsServerPlugins::initPlugins( sServerInterface ) )
   {
     QgsMessageLog::logMessage( QStringLiteral( "No server python plugins are available" ), QStringLiteral( "Server" ), Qgis::MessageLevel::Info );
   }
