@@ -49,16 +49,17 @@ extern "C"
 #include <grass/version.h>
 }
 
-#define TINY_VALUE  std::numeric_limits<double>::epsilon() * 20
+#define TINY_VALUE std::numeric_limits<double>::epsilon() * 20
 
 // Feature + GRASS primitive type
 class TestQgsGrassFeature : public QgsFeature
 {
   public:
     TestQgsGrassFeature() { setValid( true ); }
-    explicit TestQgsGrassFeature( int type ) : grassType( type ) { setValid( true ); }
+    explicit TestQgsGrassFeature( int type )
+      : grassType( type ) { setValid( true ); }
 
-    int grassType =  0 ;
+    int grassType = 0;
 };
 
 // Command which can be composed of more GRASS features, e.g. boundaries + centroid equivalent
@@ -87,13 +88,13 @@ class TestQgsGrassCommand
     {}
 
     QString toString() const;
-    Command command =  AddFeature ;
+    Command command = AddFeature;
     // some commands (in case of multiple commands making single change) must not be verified
-    bool verify =  true ;
+    bool verify = true;
 
     QList<TestQgsGrassFeature> grassFeatures;
     QgsFeature expectedFeature; // simple feature for verification
-    QgsFeatureId fid =  0 ;
+    QgsFeatureId fid = 0;
     QgsField field;
     QgsGeometry *geometry = nullptr;
     QVariant value;
@@ -126,13 +127,13 @@ QString TestQgsGrassCommand::toString() const
     {
       if ( grassFeature.hasGeometry() )
       {
-        string += "<br>grass: " + grassFeature.geometry().asWkt( 1 );
+        string += "grass: " + grassFeature.geometry().asWkt( 1 );
       }
     }
 
     if ( expectedFeature.hasGeometry() )
     {
-      string += "<br>expected: " + expectedFeature.geometry().asWkt( 1 );
+      string += "expected: " + expectedFeature.geometry().asWkt( 1 );
     }
   }
   else if ( command == DeleteFeature )
@@ -186,15 +187,16 @@ class TestQgsGrassCommandGroup
  * \ingroup UnitTests
  * This is a unit test for the QgsRasterLayer class.
  */
-class TestQgsGrassProvider: public QgsTest
+class TestQgsGrassProvider : public QgsTest
 {
     Q_OBJECT
 
   public:
-    TestQgsGrassProvider() : QgsTest( QStringLiteral( "Grass provider tests" ) ) {}
+    TestQgsGrassProvider()
+      : QgsTest( QStringLiteral( "Grass provider tests" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
+    void initTestCase(); // will be called before the first testfunction is executed.
 
     void fatalError();
     void locations();
@@ -208,6 +210,7 @@ class TestQgsGrassProvider: public QgsTest
     void rasterImport();
     void vectorImport();
     void edit();
+
   private:
     void reportRow( const QString &message );
     void reportHeader( const QString &message );
@@ -228,7 +231,7 @@ class TestQgsGrassProvider: public QgsTest
     bool compare( QList<QgsFeature> features, QList<QgsFeature> expectedFeatures, bool &ok );
     bool compare( QMap<QString, QgsVectorLayer *> layers, bool &ok );
     bool compare( QString uri, QgsVectorLayer *expectedLayer, bool &ok );
-    QList< TestQgsGrassCommandGroup > createCommands();
+    QList<TestQgsGrassCommandGroup> createCommands();
     QList<QgsFeature> getFeatures( QgsVectorLayer *layer );
     bool setAttributes( QgsFeature &feature, const QMap<QString, QVariant> &attributes );
     QString mGisdbase;
@@ -236,15 +239,20 @@ class TestQgsGrassProvider: public QgsTest
     QString mBuildMapset;
 };
 
-#define GVERIFY(x) QVERIFY( verify(x) )
+#define GVERIFY( x ) QVERIFY( verify( x ) )
 
 void TestQgsGrassProvider::reportRow( const QString &message )
 {
-  mReport += message + "<br>\n";
+  for ( const QString &line : message.split( '\n' ) )
+  {
+    qDebug() << line;
+  }
 }
 void TestQgsGrassProvider::reportHeader( const QString &message )
 {
-  mReport += "<h2>" + message + "</h2>\n";
+  qDebug() << "------";
+  qDebug() << message;
+  qDebug() << "------";
 }
 
 //runs before all tests
@@ -261,8 +269,8 @@ void TestQgsGrassProvider::initTestCase()
   QgsApplication::initQgis();
   QString mySettings = QgsApplication::showSettings();
   mySettings = mySettings.replace( QLatin1String( "\n" ), QLatin1String( "<br />\n" ) );
-  mReport += QStringLiteral( "<h1>GRASS %1 provider tests</h1>\n" ).arg( GRASS_BUILD_VERSION );
-  mReport += "<p>" + mySettings + "</p>\n";
+  reportHeader( QStringLiteral( "<h1>GRASS %1 provider tests</h1>\n" ).arg( GRASS_BUILD_VERSION ) );
+  reportRow( mySettings );
 
 #ifndef Q_OS_WIN
   reportRow( "LD_LIBRARY_PATH: " + QString( getenv( "LD_LIBRARY_PATH" ) ) );
@@ -374,11 +382,11 @@ void TestQgsGrassProvider::mapsets()
 
   QStringList expectedMapsets;
   expectedMapsets << QStringLiteral( "PERMANENT" ) << QStringLiteral( "test" ) << QStringLiteral( "test6" ) << QStringLiteral( "test7" ) << QStringLiteral( "test8" );
-  QStringList mapsets = QgsGrass::mapsets( tmpGisdbase,  mLocation );
+  QStringList mapsets = QgsGrass::mapsets( tmpGisdbase, mLocation );
   reportRow( "expectedMapsets: " + expectedMapsets.join( QLatin1String( ", " ) ) );
   reportRow( "mapsets: " + mapsets.join( QLatin1String( ", " ) ) );
   compare( expectedMapsets, mapsets, ok );
-  QgsGrass::setLocation( tmpGisdbase,  mLocation ); // for G_is_mapset_in_search_path
+  QgsGrass::setLocation( tmpGisdbase, mLocation ); // for G_is_mapset_in_search_path
   // Disabled because adding of all mapsets to search path was disabled in setLocation()
 #if 0
   Q_FOREACH ( QString expectedMapset, expectedMapsets )
@@ -440,7 +448,7 @@ void TestQgsGrassProvider::maps()
   bool ok = true;
   QStringList expectedVectors;
   expectedVectors << QStringLiteral( "test" );
-  QStringList vectors = QgsGrass::vectors( mGisdbase,  mLocation, mBuildMapset );
+  QStringList vectors = QgsGrass::vectors( mGisdbase, mLocation, mBuildMapset );
   reportRow( "expectedVectors: " + expectedVectors.join( QLatin1String( ", " ) ) );
   reportRow( "vectors: " + vectors.join( QLatin1String( ", " ) ) );
   compare( expectedVectors, vectors, ok );
@@ -448,7 +456,7 @@ void TestQgsGrassProvider::maps()
   reportRow( QLatin1String( "" ) );
   QStringList expectedRasters;
   expectedRasters << QStringLiteral( "cell" ) << QStringLiteral( "dcell" ) << QStringLiteral( "fcell" );
-  QStringList rasters = QgsGrass::rasters( mGisdbase,  mLocation, QStringLiteral( "test" ) );
+  QStringList rasters = QgsGrass::rasters( mGisdbase, mLocation, QStringLiteral( "test" ) );
   reportRow( "expectedRasters: " + expectedRasters.join( QLatin1String( ", " ) ) );
   reportRow( "rasters: " + rasters.join( QLatin1String( ", " ) ) );
   compare( expectedRasters, rasters, ok );
@@ -484,7 +492,7 @@ void TestQgsGrassProvider::vectorLayers()
 
 void TestQgsGrassProvider::invalidLayer()
 {
-  std::unique_ptr< QgsVectorLayer > brokenLayer = std::make_unique< QgsVectorLayer >( QStringLiteral( "/not/valid" ), QStringLiteral( "test" ), QStringLiteral( "grass" ) );
+  auto brokenLayer = std::make_unique<QgsVectorLayer>( QStringLiteral( "/not/valid" ), QStringLiteral( "test" ), QStringLiteral( "grass" ) );
   QVERIFY( !brokenLayer->isValid() );
   QgsVectorDataProvider *provider = brokenLayer->dataProvider();
   QVERIFY( provider );
@@ -552,8 +560,7 @@ void TestQgsGrassProvider::info()
     es = expectedStats.value( map );
     // TODO: QgsGrass::info() may open dialog window on error which blocks tests
     QString error;
-    QHash<QString, QString> info = QgsGrass::info( mGisdbase, mLocation, QStringLiteral( "test" ), map, QgsGrassObject::Raster, QStringLiteral( "stats" ),
-                                   expectedExtent, 10, 10, 5000, error );
+    QHash<QString, QString> info = QgsGrass::info( mGisdbase, mLocation, QStringLiteral( "test" ), map, QgsGrassObject::Raster, QStringLiteral( "stats" ), expectedExtent, 10, 10, 5000, error );
     if ( !error.isEmpty() )
     {
       ok = false;
@@ -566,8 +573,8 @@ void TestQgsGrassProvider::info()
     s.minimumValue = info[QStringLiteral( "MIN" )].toDouble();
     s.maximumValue = info[QStringLiteral( "MAX" )].toDouble();
 
-    reportRow( QStringLiteral( "expectedStats: min = %1 max = %2" ).arg( es.minimumValue ).arg( es.maximumValue ) ) ;
-    reportRow( QStringLiteral( "stats: min = %1 max = %2" ).arg( s.minimumValue ).arg( s.maximumValue ) ) ;
+    reportRow( QStringLiteral( "expectedStats: min = %1 max = %2" ).arg( es.minimumValue ).arg( es.maximumValue ) );
+    reportRow( QStringLiteral( "stats: min = %1 max = %2" ).arg( s.minimumValue ).arg( s.maximumValue ) );
     compare( es.minimumValue, s.minimumValue, ok );
     compare( es.maximumValue, s.maximumValue, ok );
 
@@ -619,7 +626,7 @@ void TestQgsGrassProvider::info()
 void TestQgsGrassProvider::crsEpsg3857()
 {
   QString error;
-  const QgsCoordinateReferenceSystem crs = QgsGrass::crs( mGisdbase,  QStringLiteral( "webmerc" ), error );
+  const QgsCoordinateReferenceSystem crs = QgsGrass::crs( mGisdbase, QStringLiteral( "webmerc" ), error );
   QCOMPARE( error, QString() );
   QCOMPARE( crs.authid(), QStringLiteral( "EPSG:3857" ) );
 }
@@ -638,7 +645,7 @@ bool TestQgsGrassProvider::copyRecursively( const QString &srcFilePath, const QS
       if ( error )
       {
         *error = QCoreApplication::translate( "Utils::FileUtils", "Failed to create directory '%1'." )
-                 .arg( QDir::toNativeSeparators( tgtFilePath ) );
+                   .arg( QDir::toNativeSeparators( tgtFilePath ) );
         return false;
       }
     }
@@ -661,8 +668,7 @@ bool TestQgsGrassProvider::copyRecursively( const QString &srcFilePath, const QS
       if ( error )
       {
         *error = QCoreApplication::translate( "Utils::FileUtils", "Could not copy file '%1' to '%2'." )
-                 .arg( QDir::toNativeSeparators( srcFilePath ),
-                       QDir::toNativeSeparators( tgtFilePath ) );
+                   .arg( QDir::toNativeSeparators( srcFilePath ), QDir::toNativeSeparators( tgtFilePath ) );
       }
       return false;
     }
@@ -680,8 +686,7 @@ bool TestQgsGrassProvider::removeRecursively( const QString &filePath, QString *
   if ( fileInfo.isDir() )
   {
     QDir dir( filePath );
-    QStringList fileNames = dir.entryList( QDir::Files | QDir::Hidden
-                                           | QDir::System | QDir::Dirs | QDir::NoDotAndDotDot );
+    QStringList fileNames = dir.entryList( QDir::Files | QDir::Hidden | QDir::System | QDir::Dirs | QDir::NoDotAndDotDot );
     Q_FOREACH ( const QString &fileName, fileNames )
     {
       if ( !removeRecursively( filePath + QLatin1Char( '/' ) + fileName, error ) )
@@ -693,7 +698,7 @@ bool TestQgsGrassProvider::removeRecursively( const QString &filePath, QString *
       if ( error )
       {
         *error = QCoreApplication::translate( "Utils::FileUtils", "Failed to remove directory '%1'." )
-                 .arg( QDir::toNativeSeparators( filePath ) );
+                   .arg( QDir::toNativeSeparators( filePath ) );
       }
       return false;
     }
@@ -705,7 +710,7 @@ bool TestQgsGrassProvider::removeRecursively( const QString &filePath, QString *
       if ( error )
       {
         *error = QCoreApplication::translate( "Utils::FileUtils", "Failed to remove file '%1'." )
-                 .arg( QDir::toNativeSeparators( filePath ) );
+                   .arg( QDir::toNativeSeparators( filePath ) );
       }
       return false;
     }
@@ -825,18 +830,16 @@ void TestQgsGrassProvider::rasterImport()
       Q_NOWARN_DEPRECATED_PUSH
       projector->setCrs( providerCrs, mapsetCrs );
       Q_NOWARN_DEPRECATED_POP
-      projector->destExtentSize( provider->extent(), provider->xSize(), provider->ySize(),
-                                 newExtent, newXSize, newYSize );
+      projector->destExtentSize( provider->extent(), provider->xSize(), provider->ySize(), newExtent, newXSize, newYSize );
 
       pipe->set( projector );
     }
 
     QgsGrassObject rasterObject( tmpGisdbase, tmpLocation, tmpMapset, name, QgsGrassObject::Raster );
-    QgsGrassRasterImport *import = new QgsGrassRasterImport( pipe, rasterObject,
-        newExtent, newXSize, newYSize );
+    QgsGrassRasterImport *import = new QgsGrassRasterImport( pipe, rasterObject, newExtent, newXSize, newYSize );
     if ( !import->import() )
     {
-      reportRow( "import failed: " +  import->error() );
+      reportRow( "import failed: " + import->error() );
       ok = false;
     }
     delete import;
@@ -889,7 +892,7 @@ void TestQgsGrassProvider::vectorImport()
     QgsGrassVectorImport *import = new QgsGrassVectorImport( provider, vectorObject );
     if ( !import->import() )
     {
-      reportRow( "import failed: " +  import->error() );
+      reportRow( "import failed: " + import->error() );
       ok = false;
     }
     delete import;
@@ -901,9 +904,9 @@ void TestQgsGrassProvider::vectorImport()
   GVERIFY( ok );
 }
 
-QList< TestQgsGrassCommandGroup > TestQgsGrassProvider::createCommands()
+QList<TestQgsGrassCommandGroup> TestQgsGrassProvider::createCommands()
 {
-  QList< TestQgsGrassCommandGroup > commandGroups;
+  QList<TestQgsGrassCommandGroup> commandGroups;
 
   TestQgsGrassCommandGroup commandGroup;
   TestQgsGrassCommand command;
@@ -1135,7 +1138,7 @@ void TestQgsGrassProvider::edit()
     return;
   }
 
-  QList< TestQgsGrassCommandGroup > commandGroups = createCommands();
+  QList<TestQgsGrassCommandGroup> commandGroups = createCommands();
 
   for ( int i = 0; i < commandGroups.size(); i++ )
   {
@@ -1165,7 +1168,7 @@ void TestQgsGrassProvider::edit()
 
     Q_FOREACH ( const TestQgsGrassCommand &command, commandGroup.commands )
     {
-      reportRow( "<br>command: " + command.toString() );
+      reportRow( "command: " + command.toString() );
       bool commandOk = true;
 
       if ( command.command == TestQgsGrassCommand::StartEditing )
@@ -1378,18 +1381,19 @@ void TestQgsGrassProvider::edit()
       }
       else if ( command.command == TestQgsGrassCommand::UndoAll )
       {
-        if ( grassLayer->undoStack()->count() != editCommands.size() ||
-             grassLayer->undoStack()->count() != expectedLayer->undoStack()->count() )
+        if ( grassLayer->undoStack()->count() != editCommands.size() || grassLayer->undoStack()->count() != expectedLayer->undoStack()->count() )
         {
           reportRow( QStringLiteral( "Different undo stack size: %1, expected: %2, editCommands: %3" )
-                     .arg( grassLayer->undoStack()->count() ).arg( expectedLayer->undoStack()->count() ).arg( editCommands.size() ) );
+                       .arg( grassLayer->undoStack()->count() )
+                       .arg( expectedLayer->undoStack()->count() )
+                       .arg( editCommands.size() ) );
           commandOk = false;
         }
         else
         {
           for ( int j = editCommands.size() - 1; j >= 0; j-- )
           {
-            reportRow( "<br>undo command: " + editCommands[j].toString() );
+            reportRow( "undo command: " + editCommands[j].toString() );
             grassLayer->undoStack()->undo();
             expectedLayer->undoStack()->undo();
             if ( !compare( expectedLayers, ok ) )
@@ -1407,18 +1411,19 @@ void TestQgsGrassProvider::edit()
       }
       else if ( command.command == TestQgsGrassCommand::RedoAll )
       {
-        if ( grassLayer->undoStack()->count() != editCommands.size() ||
-             grassLayer->undoStack()->count() != expectedLayer->undoStack()->count() )
+        if ( grassLayer->undoStack()->count() != editCommands.size() || grassLayer->undoStack()->count() != expectedLayer->undoStack()->count() )
         {
           reportRow( QStringLiteral( "Different undo stack size: %1, expected: %2, editCommands: %3" )
-                     .arg( grassLayer->undoStack()->count() ).arg( expectedLayer->undoStack()->count() ).arg( editCommands.size() ) );
+                       .arg( grassLayer->undoStack()->count() )
+                       .arg( expectedLayer->undoStack()->count() )
+                       .arg( editCommands.size() ) );
           commandOk = false;
         }
         else
         {
           for ( int j = 0; j < editCommands.size(); j++ )
           {
-            reportRow( "<br>redo command: " + editCommands[j].toString() );
+            reportRow( "redo command: " + editCommands[j].toString() );
             grassLayer->undoStack()->redo();
             expectedLayer->undoStack()->redo();
             if ( !compare( expectedLayers, ok ) )
@@ -1523,7 +1528,7 @@ bool TestQgsGrassProvider::equal( QgsFeature feature, QgsFeature expectedFeature
     if ( feature.attribute( index ) != expectedFeature.attribute( i ) )
     {
       reportRow( QStringLiteral( "Attribute name %1, value: '%2' does not match expected value: '%3'" )
-                 .arg( name, feature.attribute( index ).toString(), expectedFeature.attribute( i ).toString() ) );
+                   .arg( name, feature.attribute( index ).toString(), expectedFeature.attribute( i ).toString() ) );
       return false;
     }
   }
@@ -1551,7 +1556,7 @@ bool TestQgsGrassProvider::compare( QList<QgsFeature> features, QList<QgsFeature
     return false;
   }
   // Check if each expected feature exists in features
-  Q_FOREACH ( const QgsFeature &expectedFeature,  expectedFeatures )
+  Q_FOREACH ( const QgsFeature &expectedFeature, expectedFeatures )
   {
     bool found = false;
     Q_FOREACH ( const QgsFeature &feature, features )
