@@ -5,6 +5,7 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
+
 __author__ = "(C) 2017 by Nyall Dawson"
 __date__ = "20/10/2017"
 __copyright__ = "Copyright 2012, The QGIS Project"
@@ -23,7 +24,10 @@ from qgis.core import (
     QgsProject,
     QgsProperty,
     QgsRectangle,
-    QgsTextFormat
+    QgsTextFormat,
+    QgsLineSymbol,
+    QgsProperty,
+    QgsSymbolLayer,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -67,22 +71,28 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.grid().setAnnotationTextFormat(format)
         map.grid().setAnnotationPrecision(0)
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Left
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Top
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setBlendMode(QPainter.CompositionMode.CompositionMode_Overlay)
         map.updateBoundingRect()
@@ -208,8 +218,9 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_zebrastyle", layout,
-                                     allowed_mismatch=100)
+            self.render_layout_check(
+                "composermap_zebrastyle", layout, allowed_mismatch=100
+            )
         )
 
     def testZebraStyleSides(self):
@@ -238,31 +249,40 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.grid().setEnabled(True)
 
         map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameLeft, True)
-        map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameRight, False)
+        map.grid().setFrameSideFlag(
+            QgsLayoutItemMapGrid.FrameSideFlag.FrameRight, False
+        )
         map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameTop, False)
-        map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameBottom, False)
+        map.grid().setFrameSideFlag(
+            QgsLayoutItemMapGrid.FrameSideFlag.FrameBottom, False
+        )
         map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_zebrastyle_left", layout,
-                                     allowed_mismatch=100)
+            self.render_layout_check(
+                "composermap_zebrastyle_left", layout, allowed_mismatch=100
+            )
         )
 
         map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameTop, True)
         map.updateBoundingRect()
         self.assertTrue(
-            self.render_layout_check("composermap_zebrastyle_lefttop", layout,
-                                     allowed_mismatch=100)
+            self.render_layout_check(
+                "composermap_zebrastyle_lefttop", layout, allowed_mismatch=100
+            )
         )
 
         map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameRight, True)
         map.updateBoundingRect()
         self.assertTrue(
-            self.render_layout_check("composermap_zebrastyle_lefttopright", layout,
-                                     allowed_mismatch=100)
+            self.render_layout_check(
+                "composermap_zebrastyle_lefttopright", layout, allowed_mismatch=100
+            )
         )
 
-        map.grid().setFrameSideFlag(QgsLayoutItemMapGrid.FrameSideFlag.FrameBottom, True)
+        map.grid().setFrameSideFlag(
+            QgsLayoutItemMapGrid.FrameSideFlag.FrameBottom, True
+        )
         map.grid().setFrameStyle(QgsLayoutItemMapGrid.FrameStyle.NoFrame)
 
     def testInteriorTicks(self):
@@ -289,8 +309,9 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_interiorticks", layout,
-                                     allowed_mismatch=100)
+            self.render_layout_check(
+                "composermap_interiorticks", layout, allowed_mismatch=100
+            )
         )
 
     def testAnnotationsVariations(self):
@@ -380,27 +401,32 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Top)
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Right)
-            map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Bottom)
+            map.grid().setAnnotationPosition(
+                pos, QgsLayoutItemMapGrid.BorderSide.Bottom
+            )
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Left)
 
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.Vertical, QgsLayoutItemMapGrid.BorderSide.Top
+                QgsLayoutItemMapGrid.AnnotationDirection.Vertical,
+                QgsLayoutItemMapGrid.BorderSide.Top,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Right
+                QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+                QgsLayoutItemMapGrid.BorderSide.Right,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.BoundaryDirection, QgsLayoutItemMapGrid.BorderSide.Bottom
+                QgsLayoutItemMapGrid.AnnotationDirection.BoundaryDirection,
+                QgsLayoutItemMapGrid.BorderSide.Bottom,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.VerticalDescending, QgsLayoutItemMapGrid.BorderSide.Left
+                QgsLayoutItemMapGrid.AnnotationDirection.VerticalDescending,
+                QgsLayoutItemMapGrid.BorderSide.Left,
             )
 
             map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_annotations_variations",
-                                     layout)
+            self.render_layout_check("composermap_annotations_variations", layout)
         )
 
     def testAnnotationsVariationsRotated(self):
@@ -493,27 +519,34 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Top)
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Right)
-            map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Bottom)
+            map.grid().setAnnotationPosition(
+                pos, QgsLayoutItemMapGrid.BorderSide.Bottom
+            )
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Left)
 
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.AboveTick, QgsLayoutItemMapGrid.BorderSide.Top
+                QgsLayoutItemMapGrid.AnnotationDirection.AboveTick,
+                QgsLayoutItemMapGrid.BorderSide.Top,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.OnTick, QgsLayoutItemMapGrid.BorderSide.Right
+                QgsLayoutItemMapGrid.AnnotationDirection.OnTick,
+                QgsLayoutItemMapGrid.BorderSide.Right,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.UnderTick, QgsLayoutItemMapGrid.BorderSide.Bottom
+                QgsLayoutItemMapGrid.AnnotationDirection.UnderTick,
+                QgsLayoutItemMapGrid.BorderSide.Bottom,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.BoundaryDirection, QgsLayoutItemMapGrid.BorderSide.Left
+                QgsLayoutItemMapGrid.AnnotationDirection.BoundaryDirection,
+                QgsLayoutItemMapGrid.BorderSide.Left,
             )
 
             map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_annotations_variations_rotated",
-                                     layout)
+            self.render_layout_check(
+                "composermap_annotations_variations_rotated", layout
+            )
         )
 
     def testAnnotationsVariationsRotatedThresholds(self):
@@ -578,7 +611,9 @@ class TestQgsLayoutMapGrid(QgisTestCase):
             map.grid().setAnnotationEnabled(True)
             map.grid().setGridLineColor(QColor(0, 255, 0))
             map.grid().setGridLineWidth(0.5)
-            map.grid().setRotatedTicksLengthMode(QgsLayoutItemMapGrid.TickLengthMode.NormalizedTicks)
+            map.grid().setRotatedTicksLengthMode(
+                QgsLayoutItemMapGrid.TickLengthMode.NormalizedTicks
+            )
             map.grid().setAnnotationFont(getTestFont("Bold", 15))
             map.grid().setAnnotationFontColor(QColor(0, 0, 255, 150))
             map.grid().setAnnotationPrecision(0)
@@ -588,20 +623,26 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Top)
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Right)
-            map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Bottom)
+            map.grid().setAnnotationPosition(
+                pos, QgsLayoutItemMapGrid.BorderSide.Bottom
+            )
             map.grid().setAnnotationPosition(pos, QgsLayoutItemMapGrid.BorderSide.Left)
 
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.OnTick, QgsLayoutItemMapGrid.BorderSide.Top
+                QgsLayoutItemMapGrid.AnnotationDirection.OnTick,
+                QgsLayoutItemMapGrid.BorderSide.Top,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.OnTick, QgsLayoutItemMapGrid.BorderSide.Right
+                QgsLayoutItemMapGrid.AnnotationDirection.OnTick,
+                QgsLayoutItemMapGrid.BorderSide.Right,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.OnTick, QgsLayoutItemMapGrid.BorderSide.Bottom
+                QgsLayoutItemMapGrid.AnnotationDirection.OnTick,
+                QgsLayoutItemMapGrid.BorderSide.Bottom,
             )
             map.grid().setAnnotationDirection(
-                QgsLayoutItemMapGrid.AnnotationDirection.OnTick, QgsLayoutItemMapGrid.BorderSide.Left
+                QgsLayoutItemMapGrid.AnnotationDirection.OnTick,
+                QgsLayoutItemMapGrid.BorderSide.Left,
             )
 
             if limit_rot:
@@ -615,8 +656,9 @@ class TestQgsLayoutMapGrid(QgisTestCase):
             map.updateBoundingRect()
 
         self.assertTrue(
-            self.render_layout_check("composermap_annotations_variations_rotated_thresholds",
-                                     layout)
+            self.render_layout_check(
+                "composermap_annotations_variations_rotated_thresholds", layout
+            )
         )
 
     def testExpressionContext(self):
@@ -659,44 +701,48 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.grid().setAnnotationTextFormat(format)
         map.grid().setAnnotationPrecision(0)
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Left
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Top
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setBlendMode(QPainter.CompositionMode.CompositionMode_Overlay)
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridEnabled, QgsProperty.fromValue(True)
+            QgsLayoutObject.DataDefinedProperty.MapGridEnabled,
+            QgsProperty.fromValue(True),
         )
         map.grid().refresh()
 
-        self.assertTrue(
-            self.render_layout_check("composermap_grid",
-                                     layout)
-        )
+        self.assertTrue(self.render_layout_check("composermap_grid", layout))
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridEnabled, QgsProperty.fromValue(False)
+            QgsLayoutObject.DataDefinedProperty.MapGridEnabled,
+            QgsProperty.fromValue(False),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_disabled",
-                                     layout)
+            self.render_layout_check("composermap_datadefined_disabled", layout)
         )
 
     def testDataDefinedIntervalOffset(self):
@@ -719,22 +765,25 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridIntervalX, QgsProperty.fromValue(1500)
+            QgsLayoutObject.DataDefinedProperty.MapGridIntervalX,
+            QgsProperty.fromValue(1500),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridIntervalY, QgsProperty.fromValue(2500)
+            QgsLayoutObject.DataDefinedProperty.MapGridIntervalY,
+            QgsProperty.fromValue(2500),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridOffsetX, QgsProperty.fromValue(500)
+            QgsLayoutObject.DataDefinedProperty.MapGridOffsetX,
+            QgsProperty.fromValue(500),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridOffsetY, QgsProperty.fromValue(250)
+            QgsLayoutObject.DataDefinedProperty.MapGridOffsetY,
+            QgsProperty.fromValue(250),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_intervaloffset",
-                                     layout)
+            self.render_layout_check("composermap_datadefined_intervaloffset", layout)
         )
 
     def testDataDefinedFrameSize(self):
@@ -764,16 +813,17 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameSize, QgsProperty.fromValue(20)
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameSize,
+            QgsProperty.fromValue(20),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameMargin, QgsProperty.fromValue(10)
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameMargin,
+            QgsProperty.fromValue(10),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_framesizemargin",
-                                     layout)
+            self.render_layout_check("composermap_datadefined_framesizemargin", layout)
         )
 
     def testDataDefinedCrossSize(self):
@@ -800,13 +850,13 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridCrossSize, QgsProperty.fromValue(4)
+            QgsLayoutObject.DataDefinedProperty.MapGridCrossSize,
+            QgsProperty.fromValue(4),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_crosssize",
-                                     layout)
+            self.render_layout_check("composermap_datadefined_crosssize", layout)
         )
 
     def testDataDefinedFrameThickness(self):
@@ -836,13 +886,13 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameLineThickness, QgsProperty.fromValue(4)
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameLineThickness,
+            QgsProperty.fromValue(4),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_framethickness",
-                                     layout)
+            self.render_layout_check("composermap_datadefined_framethickness", layout)
         )
 
     def testDataDefinedAnnotationDistance(self):
@@ -869,34 +919,42 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
         map.grid().setAnnotationPrecision(0)
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Left
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Top
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setBlendMode(QPainter.CompositionMode.CompositionMode_Overlay)
         map.updateBoundingRect()
 
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridLabelDistance, QgsProperty.fromValue(10)
+            QgsLayoutObject.DataDefinedProperty.MapGridLabelDistance,
+            QgsProperty.fromValue(10),
         )
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_annotationdistance",
-                                     layout)
+            self.render_layout_check(
+                "composermap_datadefined_annotationdistance", layout
+            )
         )
 
     def testDataDefinedTicksAndAnnotationDisplay(self):
@@ -930,7 +988,9 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
         map.grid().setRotatedTicksEnabled(True)
         map.grid().setRotatedAnnotationsEnabled(True)
-        map.grid().setAnnotationDirection(QgsLayoutItemMapGrid.AnnotationDirection.OnTick)
+        map.grid().setAnnotationDirection(
+            QgsLayoutItemMapGrid.AnnotationDirection.OnTick
+        )
 
         map.grid().dataDefinedProperties().setProperty(
             QgsLayoutObject.DataDefinedProperty.MapGridAnnotationDisplayLeft,
@@ -945,26 +1005,32 @@ class TestQgsLayoutMapGrid(QgisTestCase):
             QgsProperty.fromValue("disabled"),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridAnnotationDisplayBottom, QgsProperty.fromValue("ALL")
+            QgsLayoutObject.DataDefinedProperty.MapGridAnnotationDisplayBottom,
+            QgsProperty.fromValue("ALL"),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsLeft, QgsProperty.fromValue("X_ONLY")
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsLeft,
+            QgsProperty.fromValue("X_ONLY"),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsRight, QgsProperty.fromValue("y_only")
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsRight,
+            QgsProperty.fromValue("y_only"),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsTop, QgsProperty.fromValue("DISABLED")
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsTop,
+            QgsProperty.fromValue("DISABLED"),
         )
         map.grid().dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsBottom, QgsProperty.fromValue("all")
+            QgsLayoutObject.DataDefinedProperty.MapGridFrameDivisionsBottom,
+            QgsProperty.fromValue("all"),
         )
 
         map.grid().refresh()
 
         self.assertTrue(
-            self.render_layout_check("composermap_datadefined_ticksandannotationdisplay",
-                                     layout)
+            self.render_layout_check(
+                "composermap_datadefined_ticksandannotationdisplay", layout
+            )
         )
 
     def testDynamicInterval(self):
@@ -992,54 +1058,156 @@ class TestQgsLayoutMapGrid(QgisTestCase):
 
         map.grid().setAnnotationPrecision(0)
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Left
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDisplay(
-            QgsLayoutItemMapGrid.DisplayMode.HideAll, QgsLayoutItemMapGrid.BorderSide.Top
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
         )
         map.grid().setAnnotationPosition(
-            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Right
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Right,
         )
         map.grid().setAnnotationDirection(
-            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal, QgsLayoutItemMapGrid.BorderSide.Bottom
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
         )
         map.grid().setBlendMode(QPainter.CompositionMode.CompositionMode_Overlay)
         map.updateBoundingRect()
 
         map.grid().refresh()
 
-        self.assertTrue(
-            self.render_layout_check("composermap_dynamic_5_10",
-                                     layout)
-        )
+        self.assertTrue(self.render_layout_check("composermap_dynamic_5_10", layout))
 
         map.setScale(map.scale() * 1.1)
 
-        self.assertTrue(
-            self.render_layout_check("composermap_dynamic_5_10_2",
-                                     layout)
-        )
+        self.assertTrue(self.render_layout_check("composermap_dynamic_5_10_2", layout))
 
         map.setScale(map.scale() * 1.8)
 
-        self.assertTrue(
-            self.render_layout_check("composermap_dynamic_5_10_3",
-                                     layout)
-        )
+        self.assertTrue(self.render_layout_check("composermap_dynamic_5_10_3", layout))
 
         map.grid().setMinimumIntervalWidth(10)
         map.grid().setMaximumIntervalWidth(40)
         map.grid().refresh()
 
+        self.assertTrue(self.render_layout_check("composermap_dynamic_5_10_4", layout))
+
+    def test_data_defined_symbol_no_transform(self):
+        layout = QgsLayout(QgsProject.instance())
+        layout.initializeDefaults()
+        map = QgsLayoutItemMap(layout)
+        map.attemptSetSceneRect(QRectF(20, 20, 200, 200))
+        map.setFrameEnabled(True)
+        map.setBackgroundColor(QColor(255, 255, 255))
+        layout.addLayoutItem(map)
+        myRectangle = QgsRectangle(781662.375, 3335523.125, 793062.375, 3345223.125)
+        map.setExtent(myRectangle)
+        map.grid().setEnabled(True)
+        map.grid().setUnits(QgsLayoutItemMapGrid.GridUnit.MapUnit)
+        map.grid().setIntervalX(1000)
+        map.grid().setIntervalY(1000)
+
+        symbol = QgsLineSymbol.createSimple({})
+        symbol.setWidth(3)
+        symbol.setColor(QColor(0, 0, 0))
+        symbol[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.StrokeColor,
+            QgsProperty.fromExpression(
+                "case when @grid_axis='x' and @grid_number % 5000 = 0 then 'red' when @grid_axis='y' and @grid_number %4000 = 0 then 'green' end"
+            ),
+        )
+
+        map.grid().setLineSymbol(symbol)
+
+        map.grid().setAnnotationPrecision(0)
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Right,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
+        )
+        map.updateBoundingRect()
+
+        map.grid().refresh()
+
         self.assertTrue(
-            self.render_layout_check("composermap_dynamic_5_10_4",
-                                     layout)
+            self.render_layout_check("datadefined_symbol_no_transform", layout)
+        )
+
+    def test_data_defined_symbol_transform(self):
+        layout = QgsLayout(QgsProject.instance())
+        layout.initializeDefaults()
+        map = QgsLayoutItemMap(layout)
+        map.attemptSetSceneRect(QRectF(20, 20, 200, 200))
+        map.setFrameEnabled(True)
+        map.setBackgroundColor(QColor(255, 255, 255))
+        layout.addLayoutItem(map)
+        map.setCrs(QgsCoordinateReferenceSystem("EPSG:3857"))
+        myRectangle = QgsRectangle(
+            12397416.413, -6129001.091, 18972629.404, -1697998.508
+        )
+        map.setExtent(myRectangle)
+        map.grid().setEnabled(True)
+        map.grid().setCrs(QgsCoordinateReferenceSystem("EPSG:4326"))
+        map.grid().setUnits(QgsLayoutItemMapGrid.GridUnit.MapUnit)
+        map.grid().setIntervalX(4)
+        map.grid().setIntervalY(4)
+
+        symbol = QgsLineSymbol.createSimple({})
+        symbol.setWidth(3)
+        symbol.setColor(QColor(0, 0, 0))
+        symbol[0].setDataDefinedProperty(
+            QgsSymbolLayer.Property.StrokeColor,
+            QgsProperty.fromExpression(
+                "case when @grid_axis='x' and @grid_number % 2 = 0 then 'red' when @grid_axis='y' and @grid_number %3 = 0 then 'green' end"
+            ),
+        )
+
+        map.grid().setLineSymbol(symbol)
+
+        map.grid().setAnnotationPrecision(0)
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Right,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
+        )
+        map.updateBoundingRect()
+
+        map.grid().refresh()
+
+        self.assertTrue(
+            self.render_layout_check("datadefined_symbol_transform", layout)
         )
 
     def testCrsChanged(self):
@@ -1078,7 +1246,8 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         self.assertEqual(len(spy), 6)
         # data defined crs
         map.dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapCrs, QgsProperty.fromValue("EPSG:4283")
+            QgsLayoutObject.DataDefinedProperty.MapCrs,
+            QgsProperty.fromValue("EPSG:4283"),
         )
         self.assertEqual(len(spy), 6)
         map.refresh()
@@ -1090,13 +1259,83 @@ class TestQgsLayoutMapGrid(QgisTestCase):
         grid.setCrs(QgsCoordinateReferenceSystem("EPSG:3857"))
         self.assertEqual(len(spy), 8)
         map.dataDefinedProperties().setProperty(
-            QgsLayoutObject.DataDefinedProperty.MapCrs, QgsProperty.fromValue("EPSG:3111")
+            QgsLayoutObject.DataDefinedProperty.MapCrs,
+            QgsProperty.fromValue("EPSG:3111"),
         )
         map.refresh()
         self.assertEqual(len(spy), 8)
         grid.setCrs(QgsCoordinateReferenceSystem("EPSG:3111"))
         self.assertEqual(len(spy), 9)
 
+    def testCopyGrid(self):
+        layout = QgsLayout(QgsProject.instance())
+        layout.initializeDefaults()
+        map = QgsLayoutItemMap(layout)
+        map.attemptSetSceneRect(QRectF(20, 20, 200, 100))
+        map.setFrameEnabled(True)
+        map.setBackgroundColor(QColor(150, 100, 100))
+        layout.addLayoutItem(map)
+        myRectangle = QgsRectangle(781662.375, 3339523.125, 793062.375, 3345223.125)
+        map.setExtent(myRectangle)
+        map.grid().setEnabled(True)
+        map.grid().setIntervalX(2000)
+        map.grid().setIntervalY(2000)
+        map.grid().setAnnotationEnabled(True)
+        map.grid().setGridLineColor(QColor(0, 255, 0))
+        map.grid().setGridLineWidth(0.5)
+
+        format = QgsTextFormat.fromQFont(getTestFont("Bold", 20))
+        format.setColor(QColor(255, 0, 0))
+        format.setOpacity(150 / 255)
+        map.grid().setAnnotationTextFormat(format)
+
+        map.grid().setAnnotationPrecision(0)
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Left,
+        )
+        map.grid().setAnnotationPosition(
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Right,
+        )
+        map.grid().setAnnotationDisplay(
+            QgsLayoutItemMapGrid.DisplayMode.HideAll,
+            QgsLayoutItemMapGrid.BorderSide.Top,
+        )
+        map.grid().setAnnotationPosition(
+            QgsLayoutItemMapGrid.AnnotationPosition.OutsideMapFrame,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
+        )
+        map.grid().setAnnotationDirection(
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Right,
+        )
+        map.grid().setAnnotationDirection(
+            QgsLayoutItemMapGrid.AnnotationDirection.Horizontal,
+            QgsLayoutItemMapGrid.BorderSide.Bottom,
+        )
+        map.grid().setBlendMode(QPainter.CompositionMode.CompositionMode_Overlay)
+        map.updateBoundingRect()
+
+        map.grid().dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.MapGridLabelDistance,
+            QgsProperty.fromValue(10),
+        )
+        map.grid().refresh()
+
+        source_grid = map.grid()
+        grid = QgsLayoutItemMapGrid("testGrid", map)
+        grid.copyProperties(source_grid)
+        map.grids().removeGrid(source_grid.id())
+        self.assertEqual(map.grids().size(), 0)
+        map.grids().addGrid(grid)
+        map.grid().refresh()
+        self.assertTrue(
+            self.render_layout_check(
+                "composermap_datadefined_annotationdistance", layout
+            )
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
